/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Application Module
 */

import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { HttpClientModule } from '@angular/common/http';

import { ActionReducer, StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';
import { StoreDevtoolsModule } from '@ngrx/store-devtools';
import { environment } from 'src/environments/environment';

import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';

import { ConfigModule } from '@shared/config/config.module';
import { AuthModule } from '@auth/auth.module';
import { NotificationsModule } from '@shared/notifications/notifications.module';

import { actions as authActions } from '@auth/state';
import { SiteModule } from '@site/site.module';
import { CompaniesModule } from '@companies/companies.module';
import { LocationsModule } from '@locations/locations.module';
import { UsersModule } from '@users/users.module';
import { ProductsModule } from '@products/products.module';
import { SoftwareModule } from '@software/software.module';
import { HashLocationStrategy, LocationStrategy } from '@angular/common';

@NgModule({
  declarations: [AppComponent],
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    HttpClientModule,
    StoreModule.forRoot({}, { metaReducers: [resetStore] }),
    EffectsModule.forRoot(),
    StoreDevtoolsModule.instrument({
      maxAge: 25,
      logOnly: environment.production,
    }),
    ConfigModule.forRoot(environment),
    AppRoutingModule,
    AuthModule,
    NotificationsModule,

    // We need to import the modules from the App module in order to
    // make sure that their redux state is available to other modules.
    SiteModule,
    CompaniesModule,
    LocationsModule,
    UsersModule,
    ProductsModule,
    SoftwareModule,
  ],
  bootstrap: [AppComponent],
})
export class AppModule {}

// This is a meta-reducer, used to clear the entire store upon log-out.
// Meta-reducers are like middleware for Redux, they can be used to
// intercept actions going into the store before other actions are executed.
export function resetStore(reducer: ActionReducer<any>): ActionReducer<any> {
  return function (state, action) {
    if (action.type === authActions.logOut.type) {
      return reducer({}, action);
    }

    return reducer(state, action);
  };
}
