/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Auth Module
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { AuthService } from './auth.service';
import { AuthTokenInterceptor } from './interceptors/auth-token.interceptor';
import { AuthPrivate } from './guards/auth-private.guard';
import { AuthPublic } from './guards/auth-public.guard';
import { AuthHasCredentials } from './guards/auth-has-credentials.guard';

import { state, modelEffects, uiEffects } from './state';

@NgModule({
  imports: [
    CommonModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
  ],
  providers: [
    { provide: HTTP_INTERCEPTORS, useClass: AuthTokenInterceptor, multi: true },
    AuthService,
    AuthPrivate,
    AuthPublic,
    AuthHasCredentials,
  ],
})
export class AuthModule {}
