/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * AuthPublic Guard
 */

import { Injectable } from '@angular/core';
import { Router, CanActivate } from '@angular/router';
import { Store, select } from '@ngrx/store';
import { map } from 'rxjs/operators';
import { selectors } from '../state';
import { IAuthUserData } from '../models';
import { actions as notificationsActions } from '@shared/notifications';

@Injectable()
export class AuthPublic implements CanActivate {
  constructor(private _store: Store, private _router: Router) {}

  canActivate() {
    return this._store.pipe(select(selectors.selectUser)).pipe(
      map((userData?: IAuthUserData) => {
        if (userData) {
          // There is already user data in the current state.
          // Block the route and show a warning.
          this._store.dispatch(
            notificationsActions.push({
              item: {
                level: 'warning',
                body: 'You are already signed in!',
              },
            })
          );

          //this.return();
          //return false;
        }
        return true;
      })
    );
  }

  return() {
    window.setTimeout(() => this._router.navigate(['/']));
  }
}
