import { Injectable } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { of } from 'rxjs';
import { map, mergeMap, catchError } from 'rxjs/operators';
import { AuthService } from '../auth.service';
import * as actions from './actions';

@Injectable()
export class modelEffects {
  constructor(private _actions$: Actions, private _authService: AuthService) {}

  logIn$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.logIn),
      mergeMap((action) =>
        this._authService.logIn(action.loginData).pipe(
          map((userData) => actions.logInSuccess({ userData })),
          catchError(() => of(actions.logInError()))
        )
      )
    )
  );

  logOut$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.logOut),
      mergeMap((action) =>
        this._authService.logOut(action.id).pipe(
          map(() => actions.logOutSuccess()),
          catchError(() => of(actions.logOutError()))
        )
      )
    )
  );

  loadUserData$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.loadUserData),
      map(() => {
        const userData = this._authService.loadUserData();
        return actions.loadUserDataSuccess({ userData });
      })
    )
  );
}
