import { createReducer, on, Action } from '@ngrx/store';
import * as actions from './actions';
import { IAuthUserData } from '../models';

export const FEATURE_STATE_NAME = 'auth';

export interface State {
  userData: IAuthUserData;
  loggingIn: boolean;
  loggingOut: boolean;
}

export const initialState: State = {
  userData: null,
  loggingIn: false,
  loggingOut: false,
};

const _reducer = createReducer(
  initialState,

  on(actions.logIn, (state) => ({ ...state, loggingIn: true })),
  on(actions.logInSuccess, (state, { userData }) => ({
    ...state,
    loggingIn: false,
    userData,
  })),
  on(actions.logInError, (state) => ({
    ...state,
    loggingIn: false,
  })),

  on(actions.logOut, (state) => ({
    ...state,
    loggingOut: true,
    userData: null,
  })),
  on(actions.logOutSuccess, () => initialState),
  on(actions.logOutError, (state) => ({
    ...state,
    loggingOut: false,
  })),

  on(actions.loadUserDataSuccess, (state, { userData }) => ({
    ...state,
    userData,
  }))
);

export function reducer(state: State | undefined, action: Action) {
  return _reducer(state, action);
}
