/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Companies Module
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { CompaniesService } from './companies.service';

import { CompaniesCreateComponent } from './components/create/companies-create.component';
import { CompaniesEditComponent } from './components/edit/companies-edit.component';
import { CompaniesDeleteComponent } from './components/delete/companies-delete.component';

import { state, modelEffects, uiEffects } from './state';
import { CompaniesListItemComponent } from './components/list-item/companies-list-item.component';
import { CompaniesViewComponent } from './components/view/companies-view.component';
import { CompaniesListComponent } from './components/list/companies-list.component';
import { CompaniesIndexPage } from './pages/index/companies-index.page';

import { CompanyTypePipe } from './pipes/companyType.pipe';
import { CompanyIndustryPipe } from './pipes/companyIndustry.pipe';
import { CompaniesViewPage } from './pages/view/companies-view.page';

import { LocationsModule } from '@locations';
import { UsersModule } from '@users/users.module';
import { IssuesModule } from '@issues/issues.module';
import { SystemsModule } from '@systems/systems.module';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    LocationsModule,
    UsersModule,
    IssuesModule,
    SystemsModule,
  ],
  providers: [CompaniesService],
  declarations: [
    CompaniesListItemComponent,
    CompaniesCreateComponent,
    CompaniesEditComponent,
    CompaniesDeleteComponent,
    CompaniesListComponent,
    CompaniesViewComponent,
    CompaniesIndexPage,
    CompaniesViewPage,
    CompanyTypePipe,
    CompanyIndustryPipe,
  ],
  exports: [
    CompaniesCreateComponent,
    CompaniesEditComponent,
    CompaniesDeleteComponent,
    CompaniesIndexPage,
    CompaniesViewPage,
  ],
})
export class CompaniesModule {}
