/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * CompaniesService
 */

import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { CRUDService } from '@shared/classes/CRUDService';
import { ConfigService } from '@shared/config';
import { CompanyListItemDto, CompanyWriteDto } from './dto';
import { Observable } from 'rxjs';

@Injectable()
export class CompaniesService extends CRUDService<
  CompanyListItemDto,
  CompanyWriteDto
> {
  constructor(http: HttpClient, config: ConfigService) {
    const endpoint = config.get('apiUrl') + '/companies';
    super(http, endpoint);
  }

  update(id: string, data: CompanyWriteDto): Observable<any> {
    const formData = new FormData();

    // The form calling this method has a file input. In order for
    // the backend to properly process it, we need to pass the form
    // content as a formData object.

    Object.keys(data).forEach(
      (key) => data[key] && formData.append(key, data[key])
    );

    return this.http.patch(`${this.endpoint}/${id}`, formData);
  }
}
