/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Companies Create Component
 */

import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { CompanyType, CompanyWriteDto, CompanyIndustry } from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'companies-create',
  templateUrl: 'companies-create.component.html',
})
export class CompaniesCreateComponent extends FormComponent implements OnInit {
  @Input() id: string;

  isSaving$: Observable<boolean>;
  companyTypes: any[];
  companyIndustries: any[];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._formBuilder.group(baseForm);
    this.companyTypes = this.enumToSelectItems(CompanyType);
    this.companyIndustries = this.enumToSelectItems(CompanyIndustry);
  }

  handleCompanySearch(searchText: string) {
    this._store.dispatch(actions.searchForSelection({ searchText }));
  }

  handleSubmit(item: CompanyWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
