/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Companies Edit Component
 */

import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import {
  CompanyType,
  CompanyIndustry,
  CompanyDto,
  CompanyWriteDto,
} from '../../dto';
import { baseForm } from '../baseForm';
import * as uiValidators from '@shared/ui/validators';

@Component({
  selector: 'companies-edit',
  templateUrl: 'companies-edit.component.html',
})
export class CompaniesEditComponent extends FormComponent implements OnInit {
  @Input() id: string;
  @Input() companyId: string;

  isSaving$: Observable<boolean>;
  item$: Observable<CompanyDto>;

  companyTypes: any[];
  companyIndustries: any[];

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.item$ = this._store
      .pipe(select(selectors.selectLoadedItem))
      .pipe(tap((values) => this.form.patchValue(values)));

    this.form = this._formBuilder.group({
      ...baseForm,
      file: [],
      web: [, uiValidators.url],
      logo: [],
      notes: [],
    });

    this.companyTypes = this.enumToSelectItems(CompanyType);
    this.companyIndustries = this.enumToSelectItems(CompanyIndustry);
  }

  handleSubmit(id: string, updatedItem: CompanyWriteDto) {
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
