/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Companies List Component
 */

import { Component, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { CompanyListItemDto } from '../../dto';

@Component({
  selector: 'companies-list',
  templateUrl: 'companies-list.component.html',
})
export class CompaniesListComponent implements OnInit {
  readonly MODAL_CREATE_ID = 'companies_list_create';

  items$: Observable<CompanyListItemDto[]>;
  selectedItemId$: Observable<string>;
  selectedSortOrder$: Observable<string>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.selectedItemId$ = this._store.pipe(
      select(selectors.selectCurentItemId)
    );
    this.selectedSortOrder$ = this._store.pipe(
      select(selectors.selectSortOrder)
    );
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));

    this._store.dispatch(actions.loadItems({}));
  }

  showAddNewForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_CREATE_ID })
    );
  }

  handleSelectedItem(id: string) {
    this._store.dispatch(actions.selectItem({ id }));
    this._store.dispatch(actions.loadItem({ id }));
  }

  handleSearchChange(text: string) {
    this._store.dispatch(actions.searchItems({ searchText: text }));
  }

  handleOrderItems(sortOrder: string) {
    this._store.dispatch(actions.sortItems({ sortOrder }));
  }
}
