import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import { CompanyListItemDto, CompanyDto, CompanyWriteDto } from '../dto';

export const selectItem = createAction(
  '[Companies] Select Company',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Companies/API] Load Companies',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Companies/API] Load Companies Success',
  props<{ items: CompanyListItemDto[] }>()
);
export const loadItemsError = createAction(
  '[Companies/API] Load Companies Error'
);

export const loadItem = createAction(
  '[Companies/API] Load Company',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Companies/API] Load Item Success',
  props<{ item: CompanyDto }>()
);
export const loadItemError = createAction('[Companies/API] Load Item Error');

export const loadTotal = createAction('[Companies/API] Load Total Companies');
export const loadTotalSuccess = createAction(
  '[Companies/API] Locat Total Companies Success',
  props<{ total: number }>()
);

export const addItem = createAction(
  '[Companies/API] Add Company',
  props<{ item: CompanyWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Companies/API] Add Company Success',
  props<{ item: CompanyListItemDto }>()
);
export const addItemError = createAction('[Companies/API] Add Company Error');

export const updateItem = createAction(
  '[Companies/API] Update Company',
  props<{ id: string; updatedItem: CompanyWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Companies/API] Update Company Success',
  props<{ item: Update<CompanyListItemDto> }>()
);
export const updateItemError = createAction(
  '[Companies/API] Update Company Error'
);

export const deleteItem = createAction(
  '[Companies/API] Delete Company',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Companies/API] Delete Company Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction(
  '[Companies/API] Delete Company Error'
);

// Actions for filtering
export const searchItems = createAction(
  '[Companies/API] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[Companies/API] Order Items',
  props<{ sortOrder: string }>()
);

// For select searches.
// These are different from loadItems because it will return
// just the id and name of the company.

export const searchForSelection = createAction(
  '[Companies/API] Search Companies for selection',
  props<{ searchText: string }>()
);

export const searchForSelectionSuccess = createAction(
  '[Companies/API] Search Companies for selection success',
  props<{ companies: CompanyListItemDto[] }>()
);
