import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { baseForm } from '../baseForm';

@Component({
  selector: 'issueComments-create',
  templateUrl: 'issueComments-create.component.html',
})
export class IssueCommentsCreateComponent
  extends FormComponent
  implements OnInit, OnChanges
{
  @Input() id: string;
  @Input() issueId: string;

  isSaving$: Observable<boolean>;

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.form = this._formBuilder.group(baseForm);
    this.form.get('issue').patchValue(this.issueId);
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('issueId') && this.form) {
      this.form.get('issue').patchValue(changes.issueId.currentValue);
    }
  }

  handleSubmit() {
    if (this.form.valid) {
      this._store.dispatch(actions.addItem({ item: this.form.value }));
      this.form.reset();
      this.form.get('issue').patchValue(this.issueId);
    }
  }
}
