import {
  Component,
  Input,
  OnInit,
  OnChanges,
  ChangeDetectionStrategy,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalActions } from '@shared/modal';
import { IssueCommentDto } from '../../dto';
import { SimpleChanges } from '@angular/core';

@Component({
  selector: 'issueComments-table',
  templateUrl: 'issueComments-table.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class IssueCommentsTableComponent implements OnInit, OnChanges {
  @Input() issueId: string;

  items$: Observable<IssueCommentDto[]>;
  isLoading$: Observable<boolean>;

  readonly MODAL_DELETE_CONFIRM_ID = 'issueComments_delete_confirm';

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('issueId')) {
      this._store.dispatch(
        actions.loadItems({ issueId: changes.issueId.currentValue })
      );
    }
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_DELETE_CONFIRM_ID })
    );
  }
}
