import { Injectable } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { catchError, map, mergeMap } from 'rxjs/operators';
import * as actions from './actions';
import { IssueCommentsService } from '../issueComments.service';
import { IssueCommentDto } from '../dto';
import { of } from 'rxjs';

@Injectable()
export class modelEffects {
  constructor(
    private _actions$: Actions,
    private _crudService: IssueCommentsService
  ) {}

  // Get all items from the backend.
  loadItems$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.loadItems),
      mergeMap((action) =>
        this._crudService.getForIssue(action.issueId).pipe(
          map((items: IssueCommentDto[]) =>
            actions.loadItemsSuccess({ items })
          ),
          catchError(() => of(actions.loadItemsError()))
        )
      )
    )
  );

  // Create a new item in the backend.
  addItem$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItem),
      mergeMap((action) =>
        this._crudService.create(action.item).pipe(
          map(
            (item: IssueCommentDto) => actions.addItemSuccess({ item }),
            catchError(() => of(actions.addItemError()))
          )
        )
      )
    )
  );

  // Load the details of the item created in the backend.
  loadAddedItem$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItemSuccess),
      map((action) => actions.loadItem({ id: action.item.id }))
    )
  );

  // Delete an item in the backend.
  deleteItem$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.deleteItem),
      mergeMap((action) =>
        this._crudService.delete(action.id).pipe(
          map(() => actions.deleteItemSuccess({ id: action.id })),
          catchError(() => of(actions.deleteItemError()))
        )
      )
    )
  );
}
