import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import {
  IssueType,
  IssueStatusType,
  IssuePriorityType,
  IssueWriteDto,
} from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'issues-create',
  templateUrl: 'issues-create.component.html',
})
export class IssuesCreateComponent extends FormComponent implements OnInit {
  @Input() id: string;
  @Input() systemId: string;

  isSaving$: Observable<boolean>;

  issueTypes: any[];
  issuePriorityTypes: any[];
  issueStatusTypes: any[];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._formBuilder.group(baseForm);
    this.form.get('system').patchValue(this.systemId);

    this.issueTypes = this.enumToSelectItems(IssueType);
    this.issuePriorityTypes = this.enumToSelectItems(IssuePriorityType);
    this.issueStatusTypes = this.enumToSelectItems(IssueStatusType);
  }

  handleSubmit(item: IssueWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
