import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder, Validators } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import {
  IssueType,
  IssueStatusType,
  IssuePriorityType,
  IssueDto,
  IssueWriteDto,
} from '../../dto';
import { baseForm } from '../baseForm';
import { ConfigService } from '@shared/config';

@Component({
  selector: 'issues-edit',
  templateUrl: 'issues-edit.component.html',
})
export class IssuesEditComponent extends FormComponent implements OnInit {
  @Input() id: string;

  isSaving$: Observable<boolean>;
  item$: Observable<IssueDto>;

  issueTypes: any[];
  issuePriorityTypes: any[];
  issueStatusTypes: any[];

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  innerspecId: string;

  constructor(
    private _formBuilder: FormBuilder,
    private _store: Store,
    private _config: ConfigService
  ) {
    super();
    this.innerspecId = this._config.get('innerspecCompanyId');
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.item$ = this._store.pipe(
      select(selectors.selectLoadedItem),
      tap((values) =>
        this.form.patchValue({
          ...values,
          system: values.systemId,
          agent: values.agentId,
        })
      )
    );

    this.form = this._formBuilder.group({
      ...baseForm,
      priority: [, Validators.required],
      status: [, Validators.required],
      agent: [],
      notes: [],
    });

    this.issueTypes = this.enumToSelectItems(IssueType);
    this.issuePriorityTypes = this.enumToSelectItems(IssuePriorityType);
    this.issueStatusTypes = this.enumToSelectItems(IssueStatusType);
  }

  handleSubmit(id: string, updatedItem: IssueWriteDto) {
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
