import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
  ChangeDetectionStrategy,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { IssueListItemDto } from '../../dto';

@Component({
  selector: 'issues-table',
  templateUrl: 'issues-table.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class IssuesTableComponent implements OnInit, OnChanges {
  @Input() systemId: string;

  items$: Observable<IssueListItemDto[]>;
  isLoading$: Observable<boolean>;

  readonly MODAL_CREATE_ID = 'issues_create_form';
  readonly MODAL_DELETE_CONFIRM_ID = 'issues_delete_confirm';

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('systemId')) {
      this._store.dispatch(
        actions.loadItemsForModel({ model: 'system', id: this.systemId })
      );
    }
  }

  showCreateForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_CREATE_ID })
    );
  }

  selectLoaction(id: string) {
    this._store.dispatch(actions.selectItem({ id }));
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_DELETE_CONFIRM_ID })
    );
  }
}
