import { ChangeDetectionStrategy, Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { IssueDto } from '../../dto';

@Component({
  selector: 'issues-view',
  templateUrl: 'issues-view.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class IssuesViewComponent implements OnInit {
  @Input() singlePage: boolean;

  readonly MODAL_EDIT_ID = 'issues_view_edit';
  readonly MODAL_CONFIRM_DELETE_ID = 'issues_view_confirm_delete';

  item$: Observable<IssueDto>;
  isLoading$: Observable<boolean>;

  tabItems = [
    { id: 'comments', label: 'Comments' },
    { id: 'attachments', label: 'Attachments' },
  ];

  constructor(private _store: Store) {}

  ngOnInit() {
    this.item$ = this._store.pipe(select(selectors.selectLoadedItem));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItem));
  }

  showEditForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_EDIT_ID })
    );
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_CONFIRM_DELETE_ID })
    );
  }

  handleDeleteItem(id: string) {
    this._store.dispatch(actions.deleteItem({ id }));
  }

  getAuthor(item: IssueDto) {
    return {
      id: item.authorId,
      name: item.authorName,
    };
  }
}
