import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { IssuesRoutingModule } from './issues-routing.module';
import { state, modelEffects, uiEffects } from './state';
import { IssuesService } from './issues.service';

import { IssuesCreateComponent } from './components/create/issues-create.component';
import { IssuesDeleteComponent } from './components/delete/issues-delete.component';
import { IssuesEditComponent } from './components/edit/issues-edit.component';
import { IssuesIndexPage } from './pages/index/issues-index.page';
import { IssuesListComponent } from './components/list/issues-list.component';
import { IssuesListItemComponent } from './components/list-item/issues-list-item.component';
import { IssuesTableComponent } from './components/table/issues-table.component';
import { IssuesViewComponent } from './components/view/issues-view.component';
import { IssuesViewPage } from './pages/view/issues-view.page';
import { IssuesBadgesComponent } from './components/badges/issues-badges.component';

import { IssueTypePipe } from './pipes/issue-type.pipe';
import { IssueStatusTypePipe } from './pipes/issue-status.pipe';
import { IssuePriorityTypePipe } from './pipes/issue-priority.pipe';

import { IssueCommentsModule } from '@issueComments/issueComments.module';
import { ModelSelectorModule } from '@shared/model-selector/model-selector.module';
import { DocumentsModule } from '@shared/documents/documents.module';
import { IssuesSimpleTableComponent } from './components/simple-table/issues-simple-table.component';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    RouterModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    //IssuesRoutingModule,
    IssueCommentsModule,
    ModelSelectorModule,
    DocumentsModule,
  ],
  providers: [IssuesService],
  declarations: [
    IssuesCreateComponent,
    IssuesDeleteComponent,
    IssuesEditComponent,
    IssuesIndexPage,
    IssuesListComponent,
    IssuesListItemComponent,
    IssuesTableComponent,
    IssuesSimpleTableComponent,
    IssuesViewComponent,
    IssuesBadgesComponent,
    IssuesViewPage,
    IssueTypePipe,
    IssueStatusTypePipe,
    IssuePriorityTypePipe,
  ],
  exports: [
    IssuesCreateComponent,
    IssuesDeleteComponent,
    IssuesEditComponent,
    IssuesIndexPage,
    IssuesTableComponent,
    IssuesSimpleTableComponent,
    IssuesViewPage,
    IssuesBadgesComponent,
  ],
})
export class IssuesModule {}
