import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { CRUDService } from '@shared/classes/CRUDService';
import { ConfigService } from '@shared/config';
import {
  ModelTypes,
  IssueTotalsDto,
  IssueListItemDto,
  IssueWriteDto,
} from './dto';
import { Observable } from 'rxjs';

@Injectable()
export class IssuesService extends CRUDService<
  IssueListItemDto,
  IssueWriteDto
> {
  constructor(http: HttpClient, config: ConfigService) {
    const endpoint = config.get('apiUrl') + '/issues';
    super(http, endpoint);
  }

  getForLocation(locationId: string): Observable<IssueListItemDto[]> {
    return this.http.get<IssueListItemDto[]>(
      `${this.endpoint}/location/${locationId}`
    );
  }

  getForSystem(systemId: string): Observable<IssueListItemDto[]> {
    return this.http.get<IssueListItemDto[]>(
      `${this.endpoint}/system/${systemId}`
    );
  }

  getForModel(
    forModel: ModelTypes,
    id: string,
    countOnly: boolean
  ): Observable<IssueTotalsDto | IssueListItemDto[]> {
    return this.http.get<IssueTotalsDto>(
      `${this.endpoint}/${forModel}/${id}?countOnly=${countOnly}`
    );
  }
}
