import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import { IssueListItemDto, IssueDto, IssueWriteDto, ModelTypes } from '../dto';

export const selectItem = createAction(
  '[Issues] Select Issue',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Issues] Load Issues',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Issues] Load Issues Success',
  props<{ items: IssueListItemDto[] }>()
);
export const loadItemsError = createAction('[Issues] Load Issues Error');

export const loadItem = createAction(
  '[Issues] Load Issue',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Issues] Load Item Success',
  props<{ item: IssueDto }>()
);
export const loadItemError = createAction('[Issues] Load Issue Error');

export const addItem = createAction(
  '[Issues] Add Issue',
  props<{ item: IssueWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Issues] Added Issue',
  props<{ item: IssueListItemDto }>()
);
export const addItemError = createAction('[Issues] Add Issue Error');

export const updateItem = createAction(
  '[Issues] Update Issue',
  props<{ id: string; updatedItem: IssueWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Issues] Update Issue Success',
  props<{ item: Update<IssueListItemDto> }>()
);
export const updateItemError = createAction('[Issues] Update Issue Error');

export const deleteItem = createAction(
  '[Issues] Delete Issue',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Issues] Delete Issue Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction('[Issues] Delete Issue Success');

// Actions for filtering
export const searchItems = createAction(
  '[Issues] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[Issues] Order Items',
  props<{ sortOrder: string }>()
);

// For select searches.
// These are different from loadItems because it will return
// just the id and name of the company.

export const searchForSelection = createAction(
  '[Issues] Search Issues for selection',
  props<{ searchText: string }>()
);

// Related data

// Load issues for other models
export const loadItemsForModel = createAction(
  '[Issues] Load Issues for Model',
  props<{ model: ModelTypes; id: string }>()
);

export const searchForSelectionSuccess = createAction(
  '[Issues] Search Issues for selection success',
  props<{ issues: IssueListItemDto[] }>()
);

// Load issues for a company
export const loadItemsForLocation = createAction(
  '[Issues] Load Issues for Location',
  props<{ locationId: string }>()
);

// Load issues for a system
export const loadItemsForSystem = createAction(
  '[Issues] Load Issues for System',
  props<{ systemId: string }>()
);
