import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { LocationType, LocationWriteDto } from '../../dto';
import { baseForm } from '../baseForm';
import { CompanySelectItemDto } from '@companies/dto';
import {
  actions as companyActions,
  selectors as companySelectors,
} from '@companies/state';

import { countries } from '../../static/countries';

@Component({
  selector: 'locations-create',
  templateUrl: 'locations-create.component.html',
})
export class LocationsCreateComponent extends FormComponent implements OnInit {
  @Input() id: string;
  @Input() companyId: string;

  isSaving$: Observable<boolean>;
  companies$: Observable<CompanySelectItemDto[]>;
  companiesLoading$: Observable<boolean>;

  locationTypes: any[];
  countries = countries;

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.companies$ = this._store.pipe(
      select(companySelectors.selectFoundForSelection)
    );
    this.companiesLoading$ = this._store.pipe(
      select(companySelectors.selectIsSearchingForSelection)
    );

    this.form = this._formBuilder.group(baseForm);
    this.locationTypes = this.enumToSelectItems(LocationType);
    this.form.get('company').patchValue(this.companyId);
  }

  handleCompanySearch(searchText: string) {
    this._store.dispatch(companyActions.searchForSelection({ searchText }));
  }

  handleSubmit(item: LocationWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
