import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder, Validators } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import { LocationType, LocationDto, LocationWriteDto } from '../../dto';
import { baseForm } from '../baseForm';
import { CompanySelectItemDto } from '@companies/dto';
import {
  actions as companyActions,
  selectors as companySelectors,
} from '@companies/state';

import { countries } from '../../static/countries';

@Component({
  selector: 'locations-edit',
  templateUrl: 'locations-edit.component.html',
})
export class LocationsEditComponent extends FormComponent implements OnInit {
  @Input() id: string;
  @Input() companyId: string;

  isSaving$: Observable<boolean>;
  item$: Observable<LocationDto>;
  companies$: Observable<CompanySelectItemDto[]>;
  companiesLoading$: Observable<boolean>;

  locationTypes: any[];
  countries = countries;

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'address', label: 'Address' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.item$ = this._store.pipe(select(selectors.selectLoadedItem)).pipe(
      tap((values) =>
        this.form.patchValue({
          ...values,
          company: { id: values?.companyId, name: values?.companyName },
        })
      )
    );

    this.companies$ = this._store.pipe(
      select(companySelectors.selectFoundForSelection)
    );
    this.companiesLoading$ = this._store.pipe(
      select(companySelectors.selectIsSearchingForSelection)
    );

    this.form = this._formBuilder.group({
      ...baseForm,
      street: [, Validators.required],
      street2: [],
      city: [, Validators.required],
      state: [, Validators.required],
      zip: [, Validators.required],
      phone: [],
      notes: [],
    });

    this.locationTypes = this.enumToSelectItems(LocationType);
  }

  handleCompanySearch(searchText: string) {
    this._store.dispatch(companyActions.searchForSelection({ searchText }));
  }

  handleSubmit(id: string, updatedItem: LocationWriteDto) {
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
