import { Component, Input, OnInit } from '@angular/core';
import { FormControl } from '@angular/forms';
import { Observable } from 'rxjs';
import { LocationListItemDto } from '../../dto';
import { Store, select } from '@ngrx/store';
import { selectors, actions } from '../../state';

@Component({
  selector: 'location-selector',
  templateUrl: 'location-selector.component.html',
})
export class LocationSelectorComponent implements OnInit {
  @Input() label: string = 'Location';
  @Input() control: FormControl;

  items$: Observable<LocationListItemDto[]>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectSelectorItems));
    this.isLoading$ = this._store.pipe(
      select(selectors.selectIsLoadingSelectorItems)
    );
  }

  handleChange(searchText: string) {
    this._store.dispatch(actions.loadSelectorItems({ searchText }));
  }
}
