import {
  ChangeDetectionStrategy,
  Component,
  Input,
  OnInit,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { LocationDto } from '../../dto';
import { tap } from 'rxjs/operators';

import { IMarker } from '@shared/ui/components/ui-map';

@Component({
  selector: 'locations-view',
  templateUrl: 'locations-view.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class LocationsViewComponent implements OnInit {
  @Input() singlePage: boolean;

  readonly MODAL_EDIT_ID = 'locations_view_edit';
  readonly MODAL_CONFIRM_DELETE_ID = 'locations_view_confirm_delete';

  item$: Observable<LocationDto>;
  isLoading$: Observable<boolean>;
  markers: IMarker[];

  constructor(private _store: Store) {}

  ngOnInit() {
    this.item$ = this._store.pipe(select(selectors.selectLoadedItem)).pipe(
      // Parse the item content to create the marker for the map.
      tap(
        (item) =>
          (this.markers = [
            {
              name: item?.name,
              coords: {
                lat: parseFloat(item?.lat),
                lng: parseFloat(item?.lng),
              },
            },
          ])
      )
    );
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItem));
  }

  showEditForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_EDIT_ID })
    );
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_CONFIRM_DELETE_ID })
    );
  }

  handleDeleteItem(id: string) {
    this._store.dispatch(actions.deleteItem({ id }));
  }
}
