import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { LocationsRoutingModule } from './locations-routing.module';
import { state, modelEffects, uiEffects } from './state';
import { LocationsService } from './locations.service';

import { LocationsCreateComponent } from './components/create/locations-create.component';
import { LocationsDeleteComponent } from './components/delete/locations-delete.component';
import { LocationsEditComponent } from './components/edit/locations-edit.component';
import { LocationSelectorComponent } from './components/selector/location-selector.component';
import { LocationsIndexPage } from './pages/index/locations-index.page';
import { LocationsListComponent } from './components/list/locations-list.component';
import { LocationsListItemComponent } from './components/list-item/locations-list-item.component';
import { LocationsTableComponent } from './components/table/locations-table.component';
import { LocationsViewComponent } from './components/view/locations-view.component';
import { LocationsViewPage } from './pages/view/locations-view.page';

import { LocationTypePipe } from './pipes/location-type.pipe';
import { LocationCountryNamePipe } from './pipes/location-country-name.pipe';

import { AuthModule } from '@auth';
import { UsersModule } from '@users/users.module';
import { SystemsModule } from '@systems/systems.module';
import { IssuesModule } from '@issues/issues.module';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    RouterModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    // LocationsRoutingModule,
    AuthModule,
    UsersModule,
    SystemsModule,
    IssuesModule,
  ],
  providers: [LocationsService],
  declarations: [
    LocationCountryNamePipe,
    LocationsCreateComponent,
    LocationsDeleteComponent,
    LocationsEditComponent,
    LocationSelectorComponent,
    LocationsIndexPage,
    LocationsListComponent,
    LocationsListItemComponent,
    LocationsTableComponent,
    LocationsViewComponent,
    LocationsViewPage,
    LocationTypePipe,
  ],
  exports: [
    LocationsCreateComponent,
    LocationsDeleteComponent,
    LocationsEditComponent,
    LocationSelectorComponent,
    LocationsIndexPage,
    LocationsTableComponent,
    LocationsViewPage,
  ],
})
export class LocationsModule {}
