import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import { LocationListItemDto, LocationDto, LocationWriteDto } from '../dto';

export const selectItem = createAction(
  '[Locations] Select Location',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Locations] Load Locations',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Locations] Load Locations Success',
  props<{ items: LocationListItemDto[] }>()
);
export const loadItemsError = createAction('[Locations] Load Locations Error');

export const loadItem = createAction(
  '[Locations] Load Location',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Locations] Load Item Success',
  props<{ item: LocationDto }>()
);
export const loadItemError = createAction('[Locations] Load Location Error');

export const addItem = createAction(
  '[Locations] Add Location',
  props<{ item: LocationWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Locations] Added Location',
  props<{ item: LocationListItemDto }>()
);
export const addItemError = createAction('[Locations] Add Location Error');

export const updateItem = createAction(
  '[Locations] Update Location',
  props<{ id: string; updatedItem: LocationWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Locations] Update Location Success',
  props<{ item: Update<LocationListItemDto> }>()
);
export const updateItemError = createAction(
  '[Locations] Update Location Error'
);

export const deleteItem = createAction(
  '[Locations] Delete Location',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Locations] Delete Location Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction(
  '[Locations] Delete Location Success'
);

// Actions for filtering
export const searchItems = createAction(
  '[Locations] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[Locations] Order Items',
  props<{ sortOrder: string }>()
);

// For select searches.
// These are different from loadItems because it will return
// just the id and name of the company.

export const searchForSelection = createAction(
  '[Locations] Search Locations for selection',
  props<{ searchText: string }>()
);

export const searchForSelectionSuccess = createAction(
  '[Locations] Search Locations for selection success',
  props<{ locations: LocationListItemDto[] }>()
);

// For Selector component

export const loadSelectorItems = createAction(
  '[Location] Load Location Selector Items',
  props<{ searchText?: string }>()
);
export const loadSelectorItemsSuccess = createAction(
  '[Location] Load Location Selector Items Success',
  props<{ items: LocationListItemDto[] }>()
);
export const loadSelectorItemsError = createAction(
  '[Location] Load Location Selector Items Error'
);

// Related data

// Load locations for a company
export const loadItemsForCompany = createAction(
  '[Locations] Load Locations for Company',
  props<{ companyId: string }>()
);
