import { Injectable } from '@angular/core';
import { createEffect, Actions, ofType } from '@ngrx/effects';
import { map } from 'rxjs/operators';
import * as actions from './actions';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { actions as notificationActions } from '@shared/notifications';

@Injectable()
export class uiEffects {
  constructor(private _actions$: Actions) {}

  setModalFormBusy$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItem, actions.updateItem, actions.deleteItem),
      map(() => modalFormActions.setModalFormBusy({ busy: true }))
    )
  );

  setModalFormNotBusy$ = createEffect(() =>
    this._actions$.pipe(
      ofType(
        actions.addItemSuccess,
        actions.updateItemSuccess,
        actions.deleteItemSuccess
      ),
      map(() => modalFormActions.setModalFormBusy({ busy: false }))
    )
  );

  setModalBusy$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.deleteItem),
      map(() => modalActions.setBusy({ busy: true }))
    )
  );

  setModalNotBusy$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.deleteItemSuccess),
      map(() => modalActions.setBusy({ busy: false }))
    )
  );

  closeModalForms$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItemSuccess, actions.updateItemSuccess),
      map(() => modalFormActions.closeModalForm())
    )
  );

  closeModals$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.deleteItemSuccess),
      map(() => modalActions.closeModal())
    )
  );

  resetModalForm$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItemSuccess, actions.updateItemSuccess),
      map(() => modalFormActions.resetModalForm())
    )
  );

  pushSuccessNotifications$ = createEffect(() =>
    this._actions$.pipe(
      ofType(
        actions.addItemSuccess,
        actions.updateItemSuccess,
        actions.deleteItemSuccess
      ),
      map((action) => {
        let body = '';

        switch (action.type) {
          case actions.addItemSuccess.type:
            body = `Location ${action.item.name} created!`;
            break;
          case actions.updateItemSuccess.type:
            body = `Location ${action.item.changes.name} updated!`;
            break;
          case actions.deleteItemSuccess.type:
            body = 'Location deleted!';
            break;
        }

        return notificationActions.push({ item: { level: 'info', body } });
      })
    )
  );
}
