import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { baseForm } from '../baseForm';
import { ProductType, ProductWriteDto } from '../../dto';

@Component({
  selector: 'products-create',
  templateUrl: 'products-create.component.html',
})
export class ProductsCreateComponent extends FormComponent implements OnInit {
  @Input() id: string;

  isSaving$: Observable<boolean>;
  productTypes: any[];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.productTypes = this.enumToSelectItems(ProductType);
    this.form = this._formBuilder.group(baseForm);
  }

  handleSubmit(item: ProductWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
