/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Products Edit Component
 */

import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import { ProductType, ProductDto, ProductWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'products-edit',
  templateUrl: 'products-edit.component.html',
})
export class ProductsEditComponent extends FormComponent implements OnInit {
  @Input() id: string;

  isSaving$: Observable<boolean>;
  item$: Observable<ProductDto>;

  productTypes: any[];

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.item$ = this._store.pipe(select(selectors.selectLoadedItem)).pipe(
      tap((values) => {
        if (values) {
          this.form.patchValue({
            ...values,
            software: { value: values.softwareId, label: values.softwareName },
          });
        }
      })
    );

    this.productTypes = this.enumToSelectItems(ProductType);

    // Initialize the form.
    this.form = this._formBuilder.group({
      ...baseForm,
      file: [],
      image: [],
      description: [],
      notes: [],
    });
  }

  handleSubmit(id: string, values: any) {
    // We need to flatten the software selector
    const updatedItem = { ...values, software: values.software.value };
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
