/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Products Module
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { state, modelEffects, uiEffects } from './state';
import { ProductsService } from './products.service';
import { ProductsRoutingModule } from './products-routing.module';

import { ProductsCreateComponent } from './components/create/products-create.component';
import { ProductsEditComponent } from './components/edit/products-edit.component';
import { ProductsDeleteComponent } from './components/delete/products-delete.component';
import { ProductsListComponent } from './components/list/products-list.component';
import { ProductsListItemComponent } from './components/list-item/products-list-item.component';
import { ProductsViewComponent } from './components/view/products-view.component';
import { ProductsIndexPage } from './pages/index/products-index.page';
import { ProductsViewPage } from './pages/view/products-view.page';

import { ProductTypePipe } from './pipes/productType.pipe';

import { AuthModule } from '@auth/auth.module';
import { ModelSelectorModule } from '@shared/model-selector';
import { DocumentsModule } from '@shared/documents/documents.module';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    // ProductsRoutingModule,
    AuthModule,
    ModelSelectorModule,
    DocumentsModule,
  ],
  providers: [ProductsService],
  declarations: [
    ProductsCreateComponent,
    ProductsDeleteComponent,
    ProductsEditComponent,
    ProductsIndexPage,
    ProductsListComponent,
    ProductsListItemComponent,
    ProductsViewComponent,
    ProductsViewPage,
    ProductTypePipe,
  ],
  exports: [
    ProductsCreateComponent,
    ProductsDeleteComponent,
    ProductsEditComponent,
    ProductsIndexPage,
    ProductsViewPage,
  ],
})
export class ProductsModule {}
