/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Products Service
 */

import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CRUDService } from '@shared/classes/CRUDService';
import { ConfigService } from '@shared/config';
import { ProductListItemDto, ProductWriteDto } from './dto';

@Injectable()
export class ProductsService extends CRUDService<
  ProductListItemDto,
  ProductWriteDto
> {
  constructor(http: HttpClient, config: ConfigService) {
    const endpoint = config.get('apiUrl') + '/products';
    super(http, endpoint);
  }

  update(id: string, data: ProductWriteDto): Observable<any> {
    const formData = new FormData();

    // The form calling this method has a file input. In order for
    // the backend to properly process it, we need to pass the form
    // content as a formData object.
    Object.keys(data).forEach(
      (key) => data[key] && formData.append(key, data[key])
    );

    return this.http.patch(`${this.endpoint}/${id}`, formData);
  }
}
