/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Products Redux Actions.
 */

import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import { ProductListItemDto, ProductDto, ProductWriteDto } from '../dto';

// CRUD actions

export const selectItem = createAction(
  '[Products] Select Product',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Products] Load Products',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Products] Load Products Success',
  props<{ items: ProductListItemDto[] }>()
);
export const loadItemsError = createAction('[Products] Load Products Error');

export const loadItem = createAction(
  '[Products] Load Product',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Products] Load Item Success',
  props<{ item: ProductDto }>()
);
export const loadItemError = createAction('[Products] Load Item Error');

export const addItem = createAction(
  '[Products] Add Product',
  props<{ item: ProductWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Products] Added Product Success',
  props<{ item: ProductListItemDto }>()
);
export const addItemError = createAction('[Products] Added Product Error');

export const updateItem = createAction(
  '[Products] Update Product',
  props<{ id: string; updatedItem: ProductWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Products] Update Product Success',
  props<{ item: Update<ProductListItemDto> }>()
);
export const updateItemError = createAction('[Products] Update Product Error');

export const deleteItem = createAction(
  '[Products] Delete Product',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Products] Delete Product Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction('[Products] Delete Product Error');

// Actions for filtering in the list

export const searchItems = createAction(
  '[Products] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[Products] Order Items',
  props<{ sortOrder: string }>()
);

// For Selector component

export const loadSelectorItems = createAction(
  '[Product] Load Product Selector Items',
  props<{ searchText?: string }>()
);
export const loadSelectorItemsSuccess = createAction(
  '[Product] Load Product Selector Items Success',
  props<{ items: ProductListItemDto[] }>()
);
export const loadSelectorItemsError = createAction(
  '[Product] Load Product Selector Items Error'
);