import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';

export class CRUDService<T> {
  constructor(private _http: HttpClient, private _appUrl: string) {}

  getAll(params?: any): Observable<any[]> {
    return this._http.get<T[]>(this._appUrl, { params });
  }

  /**
   * Fetches one item from the backend.
   *
   * @param id - ID of the item to fecth.
   * @returns Observable to the item.
   */
  getOne(id: string): Observable<any> {
    return this._http.get<T>(`${this._appUrl}/${id}`);
  }

  /**
   * Submits a new item to the backend with a POST call.
   * At the moment, this will refetch items from the backend after
   * the post operation is finished.
   *
   * @param newItem Item data to submit.
   * @returns Observable.
   */
  create(newItem: any): Observable<any> {
    return this._http.post(this._appUrl, newItem);
  }

  /**
   * Updates an item.
   * At the moment, this will refetch items from the backend after
   * the post operation is finished.
   *
   * @param id ID of the item to update.
   * @param data Data to update the item with.
   * @returns Observable
   */
  update(id: string, data: any): Observable<any> {
    return this._http.patch(`${this._appUrl}/${id}`, data);
  }

  /**
   * Delete an item in the backend given its id.
   * At the moment, this will refetch items from the backend after
   * the post operation is finished.
   *
   * @param id ID of the item to delete.
   * @returns Observable.
   */
  delete(id: string): Observable<any> {
    return this._http.delete(`${this._appUrl}/${id}`);
  }
}
