import { identifierModuleUrl } from '@angular/compiler';
import { AbstractControl, FormControl } from '@angular/forms';

export abstract class FormInputControl {
  abstract control: AbstractControl;
  abstract label: string;
  abstract required: boolean;

  constructor() {}

  isInvalid() {
    return this.control.invalid && (this.control.touched || this.control.dirty);
  }

  getErrors(): string[] {
    if (!this.control.errors) {
      return [];
    }

    const errors = this.control.errors;
    const errorNames = Object.keys(errors);
    const msgs = [];

    errorNames.forEach((item) => {
      const error = errors[item];

      switch (item) {
        case 'required':
          msgs.push(`This field is required.`);
          break;
        case 'pattern':
          msgs.push(`This field has wrong pattern.`);
          break;
        case 'email':
          msgs.push(`This is not a valid email address.`);
          break;
        case 'minlength':
          msgs.push(`Enter at least ${error.requiredLength} characters.`);
          break;
        case 'maxlength':
          msgs.push(`Maximum ${error.requiredLength} characters.`);
          break;
        default:
          msgs.push(error);
      }
    });
    return msgs;
  }
}
