import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
  ChangeDetectionStrategy,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';

@Component({
  selector: 'documents-create',
  templateUrl: 'documents-create.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DocumentsCreateComponent
  extends FormComponent
  implements OnInit, OnChanges {
  @Input() id: string;
  @Input() entityId: string;

  isSaving$: Observable<boolean>;
  form: FormGroup;

  constructor(private _fb: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._fb.group({
      file: [, Validators.required],
      description: [, Validators.required],
      entity: [this.entityId, Validators.required],
      type: ['pdf'],
    });
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('entityId') && this.form) {
      this.form.get('entity').patchValue(changes.entityId.currentValue);
    }
  }

  handleSubmit() {
    if (this.form.valid) {
      this._store.dispatch(actions.addItem({ item: this.form.value }));
    }
  }
}
