import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
  ChangeDetectionStrategy,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalActions } from '@shared/modal';
import { actions as modalFormActions } from '@shared/modal-form';
import { DocumentDto } from '../../dto';
import { FormBuilder, FormGroup } from '@angular/forms';

@Component({
  selector: 'documents-table',
  templateUrl: 'documents-table.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DocumentsTableComponent implements OnInit, OnChanges {
  @Input() entityId: string;
  @Input() showTitle: boolean = true;

  form: FormGroup;
  items$: Observable<DocumentDto[]>;
  isLoading$: Observable<boolean>;

  selectedId: string;

  readonly MODAL_CREATE_ID = 'documents_list_create';
  readonly MODAL_DELETE_CONFIRM_ID = 'documents_delete_confirm';

  constructor(private _store: Store, private _fb: FormBuilder) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));

    this.form = this._fb.group({
      file: [],
    });
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('entityId')) {
      this._store.dispatch(actions.loadItems({ entityId: this.entityId }));
    }
  }

  showAddNewForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_CREATE_ID })
    );
  }

  showConfirmDelete(id: string) {
    this.selectedId = id;
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_DELETE_CONFIRM_ID })
    );
  }

  handleDownload(id: string) {
    this._store.dispatch(actions.loadItem({ id }));
  }
}
