import { Component, Input, OnInit } from '@angular/core';
import { FormGroup } from '@angular/forms';

@Component({
  selector: 'documents-upload',
  templateUrl: 'documents-upload.component.html',
  styleUrls: ['documents-upload.component.scss'],
})
export class DocumentsUploadComponent implements OnInit {
  @Input() form: FormGroup;
  @Input() label: string = 'Select File';
  @Input() name: string;
  @Input() accept: string = 'application/pdf';
  @Input() maxSize: number = 7000000;

  required: boolean = false;
  fileName: string;
  errorMsg: string;

  ngOnInit() {}

  handleChange(event: File[]) {
    const file = event[0];

    if (file?.type !== this.accept) {
      this.errorMsg = `The file you have selected is not a valid ${this.accept}.`;
      this.clear();
      return;
    }

    if (file?.size > this.maxSize) {
      this.errorMsg = `The file you have selected is too big. The maximum size allowed is ${
        this.maxSize / 1000
      } kB.`;
      this.clear();
      return;
    }

    this.errorMsg = null;

    const reader = new FileReader();
    reader.readAsDataURL(file);
    this.form.patchValue({ file });

    this.fileName = file.name;
  }

  clear() {
    this.form.patchValue({ file: null });
    this.fileName = null;
  }

  get inputName(): string {
    return this.name || this.label.split(' ').join('_').toLowerCase();
  }

  get maxSizeAlert(): string {
    const kbs = (this.maxSize / 1000).toFixed(1);
    return `${kbs} kBs`;
  }
}
