import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpClientModule } from '@angular/common/http';
import { ReactiveFormsModule } from '@angular/forms';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { state, modelEffects, uiEffects } from './state';
import { DocumentsService } from './documents.service';
import { DocumentsUploadComponent } from './components/upload/documents-upload.component';
import { DocumentsTableComponent } from './components/table/documents-table.component';
import { DocumentsDeleteComponent } from './components/delete/documents-delete.component';
import { DocumentsCreateComponent } from './components/create/documents-create.component';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form/modal-form.module';

@NgModule({
  imports: [
    CommonModule,
    HttpClientModule,
    ReactiveFormsModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    UiModule,
    ModalModule,
    ModalFormModule,
  ],
  providers: [HttpClientModule, DocumentsService],
  declarations: [
    DocumentsUploadComponent,
    DocumentsTableComponent,
    DocumentsDeleteComponent,
    DocumentsCreateComponent,
  ],
  exports: [DocumentsTableComponent],
})
export class DocumentsModule {}
