import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ConfigService } from '@shared/config';
import { DocumentDto, DocumentWriteDto } from './dto';

@Injectable()
export class DocumentsService {
  private _endpoint: string;

  constructor(private _http: HttpClient, private _config: ConfigService) {
    this._endpoint = this._config.get('apiUrl') + '/documents';
  }

  upload(data: DocumentWriteDto): Observable<any> {
    const formData = new FormData();

    Object.keys(data).forEach(
      (key) => data[key] && formData.append(key, data[key])
    );

    return this._http.post(this._endpoint, formData);
  }

  download(id: string) {
    this._http
      .get(`${this._endpoint}/${id}`, { responseType: 'blob' })
      .subscribe((res) => {
        const blob = new Blob([res], { type: 'application/pdf' });
        const fileUrl = URL.createObjectURL(blob);
        window.open(fileUrl);
      });
  }

  getForEntity(entityId: string): Observable<DocumentDto[]> {
    return this._http.get<DocumentDto[]>(
      `${this._endpoint}/entity/${entityId}`
    );
  }

  delete(id: string): Observable<any> {
    return this._http.delete(`${this._endpoint}/${id}`);
  }
}
