import { Injectable } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { catchError, map, mergeMap, tap } from 'rxjs/operators';
import { of } from 'rxjs';
import * as actions from './actions';
import { DocumentsService } from '../documents.service';
import { DocumentDto } from '../dto';

@Injectable()
export class modelEffects {
  constructor(private _actions$: Actions, private _service: DocumentsService) {}

  // Get all documents for the given entity.
  loadItems$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.loadItems),
      mergeMap((action) =>
        this._service.getForEntity(action.entityId).pipe(
          map((items: DocumentDto[]) => actions.loadItemsSuccess({ items })),
          catchError(() => of(actions.loadItemsError()))
        )
      )
    )
  );

  // Download a document.
  downloadDocument$ = createEffect(
    () =>
      this._actions$.pipe(
        ofType(actions.loadItem),
        tap((action) => this._service.download(action.id))
      ),
    { dispatch: false }
  );

  // Upload a new document.
  addItem$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItem),
      mergeMap((action) =>
        this._service.upload(action.item).pipe(
          map((item: DocumentDto) => actions.addItemSuccess({ item })),
          catchError(() => of(actions.addItemError()))
        )
      )
    )
  );

  // Delete the given document.
  deleteItem$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.deleteItem),
      mergeMap((action) =>
        this._service.delete(action.id).pipe(
          map(() => actions.deleteItemSuccess({ id: action.id })),
          catchError(() => of(actions.deleteItemError()))
        )
      )
    )
  );
}
