import { EntityState, EntityAdapter, createEntityAdapter } from '@ngrx/entity';
import { createReducer, Action, on } from '@ngrx/store';
import * as actions from './actions';
import { DocumentDto } from '../dto';

export const FEATURE_STATE_NAME = 'documents';

export interface State extends EntityState<DocumentDto> {
  selectedItemId: string;
  sortOrder: string;
  loadingItems: boolean;

  loadingItem: boolean;
  loadedItem: DocumentDto;

  savingItem: boolean;
  deletingItem: boolean;
}

export const adapter: EntityAdapter<DocumentDto> = createEntityAdapter<DocumentDto>(
  {
    sortComparer: false,
  }
);

const initialState: State = adapter.getInitialState({
  selectedItemId: null,
  sortOrder: 'ASC',
  loadingItems: false,
  loadingItem: false,
  loadedItem: null,
  savingItem: false,
  deletingItem: false,
});

const _entityReducer = createReducer(
  initialState,

  on(actions.loadItems, (state) => ({
    ...state,
    loadingItems: true,
  })),
  on(actions.loadItemsSuccess, (state, { items }) =>
    adapter.setAll(items, { ...state, loadingItems: false })
  ),
  on(actions.loadItemsError, (state) => ({ ...state, loadingItems: false })),

  on(actions.loadItem, (state) => ({
    ...state,
    loadingItem: true,
  })),
  on(actions.loadItemError, (state) => ({ ...state, loadingItem: false })),

  on(actions.addItem, (state) => ({ ...state, savingItem: true })),
  on(actions.addItemSuccess, (state, { item }) =>
    adapter.addOne(item, {
      ...state,
      savingItem: false,
      selectedItemId: item.id,
    })
  ),
  on(actions.addItemError, (state) => ({
    ...state,
    savingItem: false,
  })),

  on(actions.deleteItem, (state) => ({ ...state, deletingItem: true })),
  on(actions.deleteItemSuccess, (state, { id }) =>
    adapter.removeOne(id, { ...state, deletingItem: false, loadedItem: null })
  ),
  on(actions.deleteItemError, (state) => ({
    ...state,
    deletingItem: false,
  }))
);

export function reducer(state: State | undefined, action: Action) {
  return _entityReducer(state, action);
}
