import { Action, createReducer, on } from '@ngrx/store';
import * as modalFormActions from './modal-form.actions';

export const STATE_FEATURE_NAME = 'modal-form';

export interface IModalFormState {
  open: boolean;
  id: string;
  busy: boolean;
  reset: boolean;
}

const initialState: IModalFormState = {
  open: false,
  id: null,
  busy: false,
  reset: false,
};

const _modalReducer = createReducer(
  initialState,
  on(modalFormActions.openModalForm, (state, { id }) => ({
    ...state,
    id,
    open: true,
    reset: false,
  })),
  on(modalFormActions.closeModalForm, (state) => ({
    ...state,
    id: null,
    open: false,
  })),
  on(modalFormActions.setModalFormBusy, (state, { busy }) => ({
    ...state,
    busy,
  })),
  on(modalFormActions.resetModalForm, (state) => ({
    ...state,
    reset: true,
  }))
);

export function modalReducer(
  state: IModalFormState | undefined,
  action: Action
) {
  return _modalReducer(state, action);
}
