import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { Observable } from 'rxjs';
import { ModalType } from '../modal.interface';

import { Store, select } from '@ngrx/store';
import { selectors, actions } from '../state';

@Component({
  selector: 'modal',
  templateUrl: 'modal.component.html',
  styleUrls: ['modal.component.scss'],
})
export class ModalComponent implements OnInit {
  @Input() id: string;
  @Input() title = '';
  @Input() type = ModalType.INFO;
  @Input() acceptLabel = 'Accept';
  @Input() cancelLabel = 'Cancel';
  @Input() acceptDisabled = false;
  @Input() cancelDisabled = false;
  @Input() busy: false;

  @Output() onAccept = new EventEmitter();
  @Output() onCancel = new EventEmitter();

  id$: Observable<string>;
  isOpen$: Observable<boolean>;
  isBusy$: Observable<boolean>;

  constructor(private _store: Store) {
    this.id$ = this._store.pipe(select(selectors.selectId));
    this.isOpen$ = this._store.pipe(select(selectors.selectIsOpen));
    this.isBusy$ = this._store.pipe(select(selectors.isBusy));
  }

  ngOnInit() {}

  get isForm(): boolean {
    return this.type === ModalType.FORM;
  }

  handleAccept() {
    this.onAccept.emit(() => this.close());
  }

  handleCancel() {
    this.close();
    this.onCancel.emit();
  }

  close() {
    this._store.dispatch(actions.closeModal());
  }
}
