import { Component, Input, OnInit } from '@angular/core';
import { FormControl } from '@angular/forms';
import { Observable } from 'rxjs';
import { SoftwareListItemDto } from '@software/dto';
import { Store, select } from '@ngrx/store';
import { selectors, actions } from '@software/state';

@Component({
  selector: 'model-software-selector',
  templateUrl: 'model-software-selector.component.html',
})
export class ModelSoftwareSelectorComponent implements OnInit {
  @Input() label: string = 'Software';
  @Input() control: FormControl;

  items$: Observable<SoftwareListItemDto[]>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectSelectorItems));
    this.isLoading$ = this._store.pipe(
      select(selectors.selectIsLoadingSelectorItems)
    );
  }

  handleChange(searchText: string) {
    this._store.dispatch(actions.loadSelectorItems({ searchText }));
  }

  parseItems(items: SoftwareListItemDto[]) {
    return items.map((item) => ({
      value: item.id,
      label: `${item.pn}-${item.name}`,
    }));
  }
}
