import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
  Output,
  EventEmitter,
} from '@angular/core';
import { AbstractControl } from '@angular/forms';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { selectors, actions } from '@softwareModules/state';
import {
  SoftwareModuleListDto,
  SoftwareModuleListItemDto,
} from '@softwareModules/dto';
import { tap } from 'rxjs/operators';

@Component({
  selector: 'model-software-module-selector',
  templateUrl: 'model-software-module-selector.component.html',
})
export class ModelSoftwareModuleSelectorComponent implements OnInit, OnChanges {
  @Input() label: string = 'Software Module';
  @Input() control: AbstractControl;
  @Input() for: 'system' | 'software';
  @Input() modelId: string;

  @Output() onChange = new EventEmitter();

  items$: Observable<SoftwareModuleListItemDto[]>;
  isLoading$: Observable<boolean>;
  selectedItem$: Observable<SoftwareModuleListItemDto>;

  parsedItems: any[] = [];
  selectedItem: string;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectSelectorItems)).pipe(
      tap((items) => {
        this.parsedItems = items.map((item) => ({
          value: item.id,
          label: `${item.pn}-${item.name}`,
        }));
      })
    );

    this.isLoading$ = this._store.pipe(
      select(selectors.selectIsLoadingSelectorItems)
    );
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('modelId')) {
      this._store.dispatch(
        actions.loadSelectorItems({ forModel: this.for, id: this.modelId })
      );
    }
  }

  handleOnChange(id: string) {
    this.selectedItem = id;
    this.onChange.emit(id);
  }

  getSelectedItem(
    items: SoftwareModuleListItemDto[]
  ): SoftwareModuleListItemDto {
    return items.find((item) => item.id === this.selectedItem);
  }
}
