import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { FormControl } from '@angular/forms';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { selectors, actions } from '@users/state';
import { ModelTypes, UserListItemDto } from '@users/dto';
import { tap } from 'rxjs/operators';

@Component({
  selector: 'model-user-selector',
  templateUrl: 'model-user-selector.component.html',
})
export class ModelUserSelectorComponent implements OnInit, OnChanges {
  @Input() label: string = 'User';
  @Input() control: FormControl;
  @Input() for: ModelTypes;
  @Input() modelId: string;

  items$: Observable<UserListItemDto[]>;
  isLoading$: Observable<boolean>;
  parsedItems: any[];

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectSelectorItems)).pipe(
      tap((items) => {
        this.parsedItems = items.map((item) => ({
          value: item.id,
          label: item.name || item.email,
        }));
      })
    );
    this.isLoading$ = this._store.pipe(
      select(selectors.selectIsLoadingSelectorItems)
    );
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('modelId')) {
      this._store.dispatch(
        actions.loadSelectorItems({ forModel: this.for, id: this.modelId })
      );
    }
  }
}
