import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import {
  trigger,
  state,
  transition,
  animate,
  style,
} from '@angular/animations';
import { Notification } from '../../models';

@Component({
  selector: 'notifications-toast',
  templateUrl: 'notifications-toast.component.html',
  styleUrls: ['notifications-toast.component.scss'],
  animations: [
    trigger('notificationDestroy', [
      state('in', style({ opacity: '100' })),
      state('void', style({ opacity: '0' })),
      transition(':enter', animate('500ms ease')),
      transition(':leave', animate('500ms ease')),
    ]),
  ],
})
export class NotificationsToastComponent implements OnInit {
  @Input() item: Notification;
  @Output() onClose = new EventEmitter();

  ngOnInit() {
    setTimeout(() => this.handleOnClose(this.item.id), 5000);
  }

  get isInfo() {
    return this.item.level === 'info';
  }

  get isWarning() {
    return this.item.level === 'warning';
  }

  get isError() {
    return this.item.level === 'error';
  }

  handleOnClose(id: number) {
    this.onClose.emit(id);
  }
}
