import { EntityState, EntityAdapter, createEntityAdapter } from '@ngrx/entity';
import { createReducer, Action, on } from '@ngrx/store';
import { Notification } from '../models';
import * as actions from './actions';

export const FEATURE_STATE_NAME = 'notifications';

export interface State extends EntityState<Notification> {}

export const adapter: EntityAdapter<Notification> = createEntityAdapter<Notification>();

export const initialState: State = adapter.getInitialState();

const _reducer = createReducer(
  initialState,
  on(actions.push, (state, { item }) =>
    adapter.addOne({ ...item, id: state.ids.length + 1 }, state)
  ),
  on(actions.close, (state, { id }) => adapter.removeOne(id, state))
);

export function reducer(state: State | undefined, action: Action) {
  return _reducer(state, action);
}
