/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiAvatarComponent
 */

import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { ConfigService } from '@shared/config';

export type UiAvatarSize = 'big' | 'normal' | 'small';

@Component({
  selector: 'ui-avatar',
  templateUrl: 'ui-avatar.component.html',
  styleUrls: ['ui-avatar.component.scss'],
})
export class UiAvatarComponent implements OnInit, OnChanges {
  @Input() name: string;
  @Input() img: string;
  @Input() size: UiAvatarSize = 'normal';

  color = '#fff';
  backgroundColor = '#cad2d3';
  backgroundUrl = '';
  apiUrl = '';

  constructor(private _config: ConfigService) {
    this.apiUrl = this._config.get('apiUrl');
  }

  ngOnInit() {}

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('img') || changes.hasOwnProperty('name')) {
      this.update();
    }
  }

  update() {
    if (this.img) {
      this.backgroundUrl = `url('${this.apiUrl}/images/${this.img}')`;
      return;
    }
  }
}
