/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiInputPriceComponent
 */

import { Component, Input, OnInit } from '@angular/core';
import { AbstractControl, FormControl } from '@angular/forms';
import { FormInputControl } from '@shared/classes/FormInputControl';
import * as uiValidators from '../../validators';

@Component({
  selector: 'ui-input-price',
  templateUrl: 'ui-input-price.component.html',
})
export class UiInputPriceComponent extends FormInputControl implements OnInit {
  @Input() control: FormControl;
  @Input() label: string;
  @Input() name: string;
  @Input() min: number = 0.0;
  @Input() max: number = 9999999.99;

  required: boolean = false;

  constructor() {
    super();
  }

  ngOnInit() {
    const validator =
      this.control.validator && this.control.validator({} as AbstractControl);
    this.required = validator && validator.required;

    const validators = [uiValidators.number(this.min, this.max)];
    if (this.control.validator) {
      validators.push(this.control.validator);
    }
    this.control.setValidators(validators);
    this.control.updateValueAndValidity();
  }

  get inputName(): string {
    return this.name || this.label.split(' ').join('_').toLowerCase();
  }
}
