/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiNavbarComponent
 */
import { Component, Input, Output, EventEmitter } from '@angular/core';
import { Store, select } from '@ngrx/store';
import { Observable } from 'rxjs';
import { selectors, actions } from '../../state';

@Component({
  selector: 'ui-navbar',
  templateUrl: './ui-navbar.component.html',
  styleUrls: ['./ui-navbar.component.scss'],
})
export class UiNavbarComponent {
  @Input() title: string;
  @Input() userId: string;
  @Input() userName: string;
  @Output() onLogout = new EventEmitter();

  sidePanelIsOpen$: Observable<boolean>;

  constructor(private _store: Store) {
    this.sidePanelIsOpen$ = this._store.pipe(
      select(selectors.selectSidePanelIsOpen)
    );
  }

  handleOpenSidePanel() {
    this._store.dispatch(actions.openSidePanel());
  }

  handleCloseSidePanel() {
    this._store.dispatch(actions.closeSidePanel());
  }

  logout() {
    this.onLogout.emit();
  }
}
