import { Component, HostListener, Input, OnInit } from '@angular/core';
import { Store, select } from '@ngrx/store';
import { Observable } from 'rxjs';
import { ConfigService } from '@shared/config/config.service';
import {
  IAuthUserData,
  selectors as authSelectors,
  actions as authActions,
} from '@auth';
import { UserProfileType } from '@users/dto';
import { tap } from 'rxjs/operators';

@Component({
  selector: 'ui-page',
  templateUrl: 'ui-page.component.html',
  styleUrls: ['ui-page.component.scss'],
})
export class UiPageComponent implements OnInit {
  @Input() title: string;
  @Input() type: string;

  height: string;
  userData$: Observable<IAuthUserData>;
  userIsInnerspec = false;

  private _appName: string;

  constructor(private _config: ConfigService, private _store: Store) {
    this._appName = this._config.get('appName');
  }

  ngOnInit(): void {
    document.title = this.title
      ? `${this._appName} - ${this.title}`
      : this._appName;

    this.updateWindowHeight();

    this.userData$ = this._store
      .pipe(select(authSelectors.selectUser))
      .pipe(
        tap(
          (userData) =>
            (this.userIsInnerspec =
              UserProfileType[userData?.profile] == UserProfileType.innerspec)
        )
      );
  }

  @HostListener('window:resize')
  updateWindowHeight() {
    this.height = `${window.innerHeight}px`;
  }

  logout(id: string) {
    this._store.dispatch(authActions.logOut({ id }));
  }
}
