/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiPiechartComponent
 */

import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Value } from 'dl-chart';

export interface UiChartValue {
  name: string;
  amount: number;
  color: string;
}

@Component({
  selector: 'ui-piechart',
  templateUrl: 'ui-piechart.component.html',
  styleUrls: ['ui-piechart.component.scss'],
})
export class UiPiechartComponent implements OnInit, OnChanges {
  @Input() id: string;
  @Input() values: UiChartValue[];
  @Input() animation: false;

  parsedValues: Value[] = [];

  ngOnInit() {
    this.parseValues(this.values);
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('values')) {
      this.parseValues(changes.values.currentValue);
    }
  }

  parseValues(values: UiChartValue[]) {
    this.parsedValues = values.map(
      (value) => new Value(value.name, value.amount, value.color)
    );
  }
}
