/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiSelectComponent
 */

import { Component, Input, OnInit, Output, EventEmitter } from '@angular/core';
import { AbstractControl } from '@angular/forms';
import { FormInputControl } from '@shared/classes/FormInputControl';

@Component({
  selector: 'ui-select',
  templateUrl: 'ui-select.component.html',
})
export class UiSelectComponent extends FormInputControl implements OnInit {
  @Input() control: AbstractControl;
  @Input() label: string;
  @Input() name: string;
  @Input() items: any[];
  @Input() loading = false;
  @Input() bindValue = 'value';
  @Input() bindLabel = 'label';
  @Output() onChange = new EventEmitter();

  required: boolean = false;

  constructor() {
    super();
  }

  ngOnInit() {
    const validator =
      this.control.validator && this.control.validator({} as AbstractControl);
    this.required = validator && validator.required;
  }

  compareFn(a: any, b: any): boolean {
    return a[this.bindValue] === b;
  }

  handleSearch({ term }) {
    this.onChange.emit(term);
  }

  handleOnChange(model: any) {
    if (model) {
      this.onChange.emit(model[this.bindValue]);
    }
  }

  get inputName(): string {
    return this.name || this.label.split(' ').join('_').toLowerCase();
  }
}
