/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiTabsComponent
 */

import {
  Component,
  ContentChildren,
  Directive,
  AfterContentInit,
  Input,
  QueryList,
  TemplateRef,
} from '@angular/core';

export interface ITabItem {
  id: string;
  label: string;
  icon?: string;
  template: TemplateRef<any>;
}

@Directive({
  selector: 'ng-template[tabName]',
})
export class UiTabContentTemplateDirective {
  @Input() type: string;
  constructor(public template: TemplateRef<any>) {}
}

@Component({
  selector: 'ui-tabs',
  templateUrl: 'ui-tabs.component.html',
  styleUrls: ['ui-tabs.component.scss'],
})
export class UiTabsComponent implements AfterContentInit {
  @Input() items: ITabItem[];
  @ContentChildren(UiTabContentTemplateDirective)
  templates: QueryList<UiTabContentTemplateDirective>;

  templateRefs: TemplateRef<any>[] = [];

  getTemplate(item: ITabItem): string {
    return item.id + 'Tab';
  }

  ngAfterContentInit() {
    this.templates.forEach((x) => this.templateRefs.push(x.template));
  }
}
