/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiUploadImageComponent
 */

import { Component, Input } from '@angular/core';
import { FormGroup } from '@angular/forms';

@Component({
  selector: 'ui-upload-image',
  templateUrl: 'ui-upload-image.component.html',
  styleUrls: ['ui-upload-image.component.scss'],
})
export class UiUploadImageComponent {
  @Input() form: FormGroup;
  @Input() label: string = 'Upload Image';
  @Input() name: string;
  @Input() accept: string = 'image/jpeg';
  @Input() maxSize: number = 50000;

  loadedFile: File;
  required: boolean = false;
  imgSrc: any;
  errorMsg: string;

  handleChange(event: File[]) {
    const file = event[0];
    this.loadedFile = file;

    if (file?.type !== this.accept) {
      this.errorMsg = `The file you have selected is not a valid ${this.accept}.`;
      this.clear();
      return;
    }

    if (file?.size > this.maxSize) {
      this.errorMsg = `The file you have selected is too big. The maximum size allowed is ${
        this.maxSize / 1000
      } kB.`;
      this.clear();
      return;
    }

    this.errorMsg = null;

    const reader = new FileReader();
    reader.onload = (e) => (this.imgSrc = reader.result);
    reader.readAsDataURL(file);
    this.form.patchValue({ file });
  }

  clear() {
    this.form.patchValue({ file: null });
    this.imgSrc = null;
  }

  get inputName(): string {
    return this.name || this.label.split(' ').join('_').toLowerCase();
  }
}
