/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiViewComponent
 */

import {
  Component,
  Input,
  Output,
  TemplateRef,
  EventEmitter,
} from '@angular/core';
import { fadeInAnimation } from '../../animations';

export interface IAuthorData {
  id: string;
  name: string;
}

@Component({
  selector: 'ui-view',
  templateUrl: 'ui-view.component.html',
  animations: [fadeInAnimation()],
})
export class UiViewComponent {
  @Input() title: string;
  @Input() section: string;
  @Input() busy: boolean = false;
  @Input() item: any;
  @Input() avatarImage: string;
  @Input() avatarName: string;
  @Input() template: TemplateRef<any>;
  @Input() actionButtonsTemplate: TemplateRef<any>;
  @Input() allowEditItem = false;
  @Input() allowDeleteItem = false;

  @Output() onEdit = new EventEmitter();
  @Output() onDelete = new EventEmitter();

  get created(): string {
    return this.formatDateTime(this.item.created);
  }

  get updated(): string {
    return this.formatDateTime(this.item.updated);
  }

  formatDateTime(dateTime: string): string {
    const date = new Date(dateTime);
    const dateStr = date.toLocaleDateString(navigator.language);
    const timeStr = date.toLocaleTimeString(navigator.language);
    return `${dateStr} - ${timeStr}`;
  }

  handleEditClick() {
    this.onEdit.emit();
  }

  handleDeleteClick() {
    this.onDelete.emit();
  }
}
