/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * UiModule
 *
 * Provides a series of components that act as a shim to others
 * provided by third party libraries in order to decouple NDT-Link
 * user interface from them, ensuring an easy transition to other
 * libraries when needed in the future.
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { StoreModule } from '@ngrx/store';
import { NgSelectModule } from '@ng-select/ng-select';
import { AngularSplitModule } from 'angular-split';
import { DlPieChartModule } from 'dl-chart';

import { state } from './state';

import { UiNavbarComponent } from './components/ui-navbar/ui-navbar.component';
import { UiSidemenuComponent } from './components/ui-sidemenu/ui-sidemenu.component';
import { UiListHeaderComponent } from './components/ui-list-header/ui-list-header.component';
import { UiListComponent } from './components/ui-list/ui-list.component';
import { UiViewComponent } from './components/ui-view/ui-view.component';
import { UiInputComponent } from './components/ui-input/ui-input.component';
import { UiTextareaComponent } from './components/ui-textarea/ui-textarea.component';
import { UiSelectComponent } from './components/ui-select/ui-select.component';
import { UiViewEmptyComponent } from './components/ui-view-empty/ui-view-empty.component';
import { UiListEmptyComponent } from './components/ui-list-empty/ui-list-empty.component';
import { UiSplitComponent } from './components/ui-split/ui-split.component';
import { UiPanelComponent } from './components/ui-panel/ui-panel.component';
import { UiPageComponent } from './components/ui-page/ui-page.component';
import { UiPagePublicComponent } from './components/ui-page-public/ui-page-public.component';
import { UiAvatarComponent } from './components/ui-avatar/ui-avatar.component';
import { UiLoadingComponent } from './components/ui-loading/ui-loading.component';
import { UiProgressBarComponent } from './components/ui-progress-bar/ui-progress-bar.component';
import {
  UiTabContentTemplateDirective,
  UiTabsComponent,
} from './components/ui-tabs/ui-tabs.component';
import { UiFieldComponent } from './components/ui-field/ui-field.component';
import { UiViewLoadingComponent } from './components/ui-view-loading/ui-view-loading.component';
import { UiMoreComponent } from './components/ui-more/ui-more.component';
import { UiDateComponent } from './components/ui-date/ui-date.component';
import { UiToggleComponent } from './components/ui-toggle/ui-toggle.component';
import { UiInputPriceComponent } from './components/ui-input-price/ui-input-price.component';
import { UiUploadComponent } from './components/ui-upload/ui-upload.component';
import { UiUploadImageComponent } from './components/ui-upload-image/ui-upload-image.component';
import { UiMapComponent } from './components/ui-map/ui-map.component';
import { UiPiechartComponent } from './components/ui-piechart/ui-piechart.component';
import { UiPillComponent } from './components/ui-pill/ui-pill.component';

import { UiInitialsPipe } from './pipes/initials.pipe';
import { FocusDirective } from './directives/focus.directive';

@NgModule({
  imports: [
    CommonModule,
    ReactiveFormsModule,
    RouterModule,
    StoreModule.forFeature(state.STATE_FEATURE_NAME, state.uiReducer),
    NgSelectModule,
    AngularSplitModule,
    DlPieChartModule,
  ],
  declarations: [
    FocusDirective,
    UiInitialsPipe,
    UiAvatarComponent,
    UiFieldComponent,
    UiInputComponent,
    UiListComponent,
    UiListEmptyComponent,
    UiListHeaderComponent,
    UiLoadingComponent,
    UiProgressBarComponent,
    UiMoreComponent,
    UiNavbarComponent,
    UiPageComponent,
    UiPagePublicComponent,
    UiPanelComponent,
    UiSelectComponent,
    UiSidemenuComponent,
    UiSplitComponent,
    UiTabContentTemplateDirective,
    UiTabsComponent,
    UiTextareaComponent,
    UiViewComponent,
    UiViewEmptyComponent,
    UiViewLoadingComponent,
    UiDateComponent,
    UiToggleComponent,
    UiInputPriceComponent,
    UiUploadImageComponent,
    UiUploadComponent,
    UiMapComponent,
    UiPiechartComponent,
    UiPillComponent,
  ],
  exports: [
    FocusDirective,
    UiInitialsPipe,
    UiAvatarComponent,
    UiFieldComponent,
    UiInputComponent,
    UiListComponent,
    UiListEmptyComponent,
    UiListHeaderComponent,
    UiLoadingComponent,
    UiProgressBarComponent,
    UiMoreComponent,
    UiPageComponent,
    UiPagePublicComponent,
    UiPanelComponent,
    UiSelectComponent,
    UiSplitComponent,
    UiTabContentTemplateDirective,
    UiTabsComponent,
    UiTextareaComponent,
    UiViewComponent,
    UiViewEmptyComponent,
    UiViewLoadingComponent,
    UiDateComponent,
    UiToggleComponent,
    UiInputPriceComponent,
    UiUploadImageComponent,
    UiUploadComponent,
    UiMapComponent,
    UiPiechartComponent,
    UiPillComponent,
  ],
})
export class UiModule {}
