/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Number Form Validator
 */

import { AbstractControl, ValidatorFn } from '@angular/forms';

/**
 * Checks the content of the input box contains a valid number.
 */

export function number(min?: number, max?: number): ValidatorFn {
  return (control: AbstractControl): { [key: string]: any } | null => {
    const value = control.value;

    if (!value) {
      return null;
    }

    if (isNaN(value)) {
      return {
        number: 'This is not a valid number',
      };
    }

    if (min !== null && value < min) {
      return {
        number: `Enter a number greater than ${min}`,
      };
    }

    if (max !== null && value > max) {
      return {
        number: `Enter a number less than ${max}`,
      };
    }

    return null;
  };
}
