/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Password Form Validator
 */

import { AbstractControl, ValidatorFn } from '@angular/forms';

/**
 * Checks the content of the input box a password that has at least
 * and must contain one upper case letter, one lower case letter,
 * one digit, and one special character.
 */

export function password(): ValidatorFn {
  return (control: AbstractControl): { [key: string]: any } | null => {
    if (!control.value) {
      return null;
    }

    const regex = new RegExp(
      /^(?=.*?[A-Z])(?=.*?[a-z])(?=.*?[0-9])(?=.*?[#?!@$%^&*-]).{8,}$/
    );

    if (regex.test(control.value)) {
      return null;
    }

    return {
      password: `Enter a stronger password`,
    };
  };
}
