/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Part Number Form Validator
 */

import { AbstractControl, ValidatorFn } from '@angular/forms';

/**
 * Checks the content of the input box contains the following structure:
 * PPPXNNNNN
 * Where PPP is the category prefix, X is a letter and N a digit.
 */

export function pn(family?: number, origin?: string): ValidatorFn {
  return (control: AbstractControl): { [key: string]: any } | null => {
    if (!control.value) {
      return null;
    }

    const f = family || '800';
    const o = origin || 'A';

    const regex = new RegExp(`^(${f})(${o})\\d{4}$`);

    if (regex.test(control.value)) {
      return null;
    }

    return {
      pn: `The format should be ${f}${o}NNNN, where N is a digit.`,
    };
  };
}
