import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { SiteService } from '../../site.service';
import { IssueTotalsDto } from '@issues';

@Component({
  selector: 'site-dashboard-page',
  templateUrl: 'site-dashboard.page.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SiteDashboardPage implements OnInit {
  totalCompanies$: Observable<number>;
  totalLocations$: Observable<number>;
  totalUsers$: Observable<number>;
  totalSystems$: Observable<number>;
  totalIssues$: Observable<IssueTotalsDto>;

  constructor(private _service: SiteService) {}

  ngOnInit() {
    this.totalCompanies$ = this._service.getTotalCompanies();
    this.totalLocations$ = this._service.getTotalLocations();
    this.totalUsers$ = this._service.getTotalUsers();
    this.totalSystems$ = this._service.getTotalSystems();
    this.totalIssues$ = this._service.getTotalIssues();
  }

  parseTotalIssues(totals: IssueTotalsDto) {
    const { open, pending, closed } = totals;

    return [
      { name: 'Open', amount: open, color: '#da4343d6' },
      { name: 'Pending', amount: pending, color: '#e6e50bde' },
      { name: 'Closed', amount: closed, color: '#0d9e0d8c' },
    ];
  }
}
