import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { ConfigService } from '@shared/config';
import { Observable } from 'rxjs';
import { CompaniesService } from '@companies';
import { LocationsService } from '@locations';
import { UsersService } from '@users';
import { SystemsService } from '@systems';
import { IssuesService, IssueTotalsDto } from '@issues';

@Injectable()
export class SiteService {
  paymentsUrl: string;

  constructor(
    private _http: HttpClient,
    private _config: ConfigService,
    private _companiesService: CompaniesService,
    private _locationsService: LocationsService,
    private _usersService: UsersService,
    private _systemsService: SystemsService,
    private _issuesService: IssuesService
  ) {
    this.paymentsUrl =
      this._config.get('apiUrl') + '/subscriptions/process-purchase';
  }

  getTotalCompanies(): Observable<number> {
    return this._companiesService.getCount();
  }

  getTotalLocations(): Observable<number> {
    return this._locationsService.getCount();
  }

  getTotalUsers(): Observable<number> {
    return this._usersService.getCount();
  }

  getTotalSystems(): Observable<number> {
    return this._systemsService.getCount();
  }

  getTotalIssues(): Observable<IssueTotalsDto> {
    return this._issuesService.getAll('', '', true);
  }

  processPayment(token: string, payerId: string): Observable<any> {
    console.log("SERVICE CALLED ONCE");
    return this._http.post(this.paymentsUrl, { token, payerId });
  }
}
