import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { baseForm } from '../baseForm';
import { SoftwarePlatformType, SoftwareWriteDto } from '../../dto';

@Component({
  selector: 'software-create',
  templateUrl: 'software-create.component.html',
})
export class SoftwareCreateComponent extends FormComponent implements OnInit {
  @Input() id: string;
  @Input() locationId: string;

  isSaving$: Observable<boolean>;
  softwareTypes: any[];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._formBuilder.group(baseForm);
    this.softwareTypes = this.enumToSelectItems(SoftwarePlatformType);
  }

  handleSubmit(item: SoftwareWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
