import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import { SoftwarePlatformType, SoftwareDto, SoftwareWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'software-edit',
  templateUrl: 'software-edit.component.html',
})
export class SoftwareEditComponent extends FormComponent implements OnInit {
  @Input() id: string;
  @Input() companyId: string;

  isSaving$: Observable<boolean>;
  item$: Observable<SoftwareDto>;

  softwareTypes: any[];

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    // Load the item to edit.
    // We pipe in to patch the form with the values received from the selector.
    this.item$ = this._store
      .pipe(select(selectors.selectLoadedItem))
      .pipe(tap((values) => this.form.patchValue(values)));

    // Initialize the form.
    this.form = this._formBuilder.group({
      ...baseForm,
      notes: [],
    });

    this.softwareTypes = this.enumToSelectItems(SoftwarePlatformType);
  }

  handleSubmit(id: string, updatedItem: SoftwareWriteDto) {
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
