/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Software Module
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { state, modelEffects, uiEffects } from './state';
import { SoftwareService } from './software.service';
import { SoftwareRoutingModule } from './software-routing.module';

import { SoftwareCreateComponent } from './components/create/software-create.component';
import { SoftwareDeleteComponent } from './components/delete/software-delete.component';
import { SoftwareEditComponent } from './components/edit/software-edit.component';
import { SoftwareListComponent } from './components/list/software-list.component';
import { SoftwareListItemComponent } from './components/list-item/software-list-item.component';
import { SoftwareViewComponent } from './components/view/software-view.component';
import { SoftwareIndexPage } from './pages/index/software-index.page';
import { SoftwareViewPage } from './pages/view/software-view.page';

import { SoftwareTypePipe } from './pipes/software-type.pipe';

import { AuthModule } from '@auth';
import { SoftwareModulesModule } from '@softwareModules/softwareModules.module';
import { DocumentsModule } from '@shared/documents/documents.module';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    //SoftwareRoutingModule,
    AuthModule,
    SoftwareModulesModule,
    DocumentsModule,
  ],
  providers: [SoftwareService],
  declarations: [
    SoftwareCreateComponent,
    SoftwareDeleteComponent,
    SoftwareEditComponent,
    SoftwareIndexPage,
    SoftwareListComponent,
    SoftwareListItemComponent,
    SoftwareViewComponent,
    SoftwareViewPage,
    SoftwareTypePipe,
  ],
  exports: [
    SoftwareCreateComponent,
    SoftwareDeleteComponent,
    SoftwareEditComponent,
    SoftwareIndexPage,
    SoftwareViewPage,
  ],
})
export class SoftwareModule {}
