/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Software Redux Actions.
 */

import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import { SoftwareListItemDto, SoftwareDto, SoftwareWriteDto } from '../dto';

// CRUD actions

export const selectItem = createAction(
  '[Software] Select Software',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Software] Load Software Items',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Software] Load Software Items Success',
  props<{ items: SoftwareListItemDto[] }>()
);
export const loadItemsError = createAction('[Software] Load Software Error');

export const loadItem = createAction(
  '[Software] Load Software Item',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Software] Load Software Item Success',
  props<{ item: SoftwareDto }>()
);
export const loadItemError = createAction('[Software] Load Item Error');

export const addItem = createAction(
  '[Software] Add Software',
  props<{ item: SoftwareWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Software] Added Software Success',
  props<{ item: SoftwareListItemDto }>()
);
export const addItemError = createAction('[Software] Added Software Error');

export const updateItem = createAction(
  '[Software] Update Software',
  props<{ id: string; updatedItem: SoftwareWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Software] Update Software Success',
  props<{ item: Update<SoftwareListItemDto> }>()
);
export const updateItemError = createAction('[Software] Update Software Error');

export const deleteItem = createAction(
  '[Software] Delete Software',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Software] Delete Software Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction('[Software] Delete Software Error');

// Actions for filtering in the list

export const searchItems = createAction(
  '[Software] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[Software] Order Items',
  props<{ sortOrder: string }>()
);

// For Selector component

export const loadSelectorItems = createAction(
  '[Software] Load Software Selector Items',
  props<{ searchText?: string }>()
);
export const loadSelectorItemsSuccess = createAction(
  '[Software] Load Software Selector Items Success',
  props<{ items: SoftwareListItemDto[] }>()
);
export const loadSelectorItemsError = createAction(
  '[Software] Load Software Selector Items Error'
);
