/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Redux Selectors for Software.
 */

import { createSelector } from '@ngrx/store';
import { FEATURE_STATE_NAME, State, adapter } from './reducer';

interface AppState {
  [FEATURE_STATE_NAME]: State;
}

const selectState = (state: AppState) => state[FEATURE_STATE_NAME];

const selectors = adapter.getSelectors();

export const selectItems = createSelector(selectState, selectors.selectAll);
export const selectIsLoadingItems = createSelector(
  selectState,
  (state) => state.loadingItems
);

export const selectLoadedItem = createSelector(
  selectState,
  (state) => state.loadedItem
);
export const selectIsLoadingItem = createSelector(
  selectState,
  (state) => state.loadingItems
);

export const selectCurentItemId = createSelector(
  selectState,
  (state) => state.selectedItemId
);
export const selectCurrentItem = createSelector(
  selectState,
  selectCurentItemId,
  (state, itemId) => state.entities[itemId]
);

export const selectIsSavingItem = createSelector(
  selectState,
  (state) => state.savingItem
);
export const selectIsDeletingItem = createSelector(
  selectState,
  (state) => state.deletingItem
);

export const selectSortOrder = createSelector(
  selectState,
  (state) => state.sortOrder
);

// For Selector component

export const selectSelectorItems = createSelector(
  selectState,
  (state) => state.selectorItems
);
export const selectIsLoadingSelectorItems = createSelector(
  selectState,
  (state) => state.loadingSelectorItems
);
