import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import { SoftwareModuleWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'softwareModules-create',
  templateUrl: 'softwareModules-create.component.html',
})
export class SoftwareModulesCreateComponent
  extends FormComponent
  implements OnInit, OnChanges
{
  @Input() id: string;
  @Input() softwareId: string;

  isSaving$: Observable<boolean>;

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.form = this._formBuilder.group({
      ...baseForm,
      software: this.softwareId,
    });
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.form && changes.hasOwnProperty('softwareId')) {
      this.form.get('software').patchValue(changes.softwareId.currentValue);
    }
  }

  handleSubmit(item: SoftwareModuleWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
