import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChange,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder, Validators } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import { SoftwareModuleListItemDto, SoftwareModuleWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'softwareModules-edit',
  templateUrl: 'softwareModules-edit.component.html',
})
export class SoftwareModulesEditComponent
  extends FormComponent
  implements OnInit, OnChanges
{
  @Input() id: string;
  @Input() softwareId: string;

  isSaving$: Observable<boolean>;
  item$: Observable<SoftwareModuleListItemDto>;

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'cost', label: 'Cost' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.item$ = this._store.pipe(select(selectors.selectCurrentItem)).pipe(
      tap((values) =>
        this.form.patchValue({
          ...values,
          software: values?.softwareId,
        })
      )
    );

    this.form = this._formBuilder.group({
      ...baseForm,
      notes: [],
    });
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.form && changes.hasOwnProperty('softwareId')) {
      this.form.get('software').patchValue(changes.softwareId.currentValue);
    }
  }

  handleIsFreeChange(isFree: boolean) {
    const controlNames = ['daily', 'weekly', 'monthly', 'annual', 'permanent'];

    controlNames.forEach((name) => {
      const control = this.form.get(name);
      if (!isFree) {
        control.setValidators([Validators.required]);
        control.patchValue(null);

        return;
      }

      control.patchValue(0);
      control.clearValidators();
    });
  }

  handleSubmit(id: string, updatedItem: SoftwareModuleWriteDto) {
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
