import { Component, Input, OnInit, OnChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { SoftwareModuleListItemDto } from '../../dto';

@Component({
  selector: 'softwareModules-table',
  templateUrl: 'softwareModules-table.component.html',
})
export class SoftwareModulesTableComponent implements OnInit, OnChanges {
  @Input() softwareId: string;

  items$: Observable<SoftwareModuleListItemDto[]>;
  isLoading$: Observable<boolean>;

  readonly MODAL_CREATE_ID = 'softwareModules_create_form';
  readonly MODAL_EDIT_ID = 'softwareModules_edit_form';
  readonly MODAL_DELETE_CONFIRM_ID = 'softwareModules_delete_confirm';

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges() {
    this._store.dispatch(
      actions.loadItemsForSoftware({ softwareId: this.softwareId })
    );
  }

  showCreateForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_CREATE_ID })
    );
  }

  showEditForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_EDIT_ID })
    );
  }

  selectLoaction(id: string) {
    this._store.dispatch(actions.selectItem({ id }));
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_DELETE_CONFIRM_ID })
    );
  }
}
