import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import {
  SoftwareModuleListItemDto,
  SoftwareModuleDto,
  SoftwareModuleWriteDto,
} from '../dto';

export const selectItem = createAction(
  '[SoftwareModules] Select SoftwareModule',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[SoftwareModules] Load SoftwareModules',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[SoftwareModules] Load SoftwareModules Success',
  props<{ items: SoftwareModuleListItemDto[] }>()
);
export const loadItemsError = createAction(
  '[SoftwareModules] Load SoftwareModules Error'
);

export const loadItem = createAction(
  '[SoftwareModules] Load SoftwareModule',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[SoftwareModules] Load Item Success',
  props<{ item: SoftwareModuleDto }>()
);
export const loadItemError = createAction(
  '[SoftwareModules] Load SoftwareModule Error'
);

export const addItem = createAction(
  '[SoftwareModules] Add SoftwareModule',
  props<{ item: SoftwareModuleWriteDto }>()
);
export const addItemSuccess = createAction(
  '[SoftwareModules] Added SoftwareModule',
  props<{ item: SoftwareModuleListItemDto }>()
);
export const addItemError = createAction(
  '[SoftwareModules] Add SoftwareModule Error'
);

export const updateItem = createAction(
  '[SoftwareModules] Update SoftwareModule',
  props<{ id: string; updatedItem: SoftwareModuleWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[SoftwareModules] Update SoftwareModule Success',
  props<{ item: Update<SoftwareModuleListItemDto> }>()
);
export const updateItemError = createAction(
  '[SoftwareModules] Update SoftwareModule Error'
);

export const deleteItem = createAction(
  '[SoftwareModules] Delete SoftwareModule',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[SoftwareModules] Delete SoftwareModule Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction(
  '[SoftwareModules] Delete SoftwareModule Success'
);

// Actions for filtering
export const searchItems = createAction(
  '[SoftwareModules] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[SoftwareModules] Order Items',
  props<{ sortOrder: string }>()
);

// For select searches.
// These are different from loadItems because it will return
// just the id and name of the company.

export const searchForSelection = createAction(
  '[SoftwareModules] Search SoftwareModules for selection',
  props<{ searchText: string }>()
);

export const searchForSelectionSuccess = createAction(
  '[SoftwareModules] Search SoftwareModules for selection success',
  props<{ locations: SoftwareModuleListItemDto[] }>()
);

// Related data

// Load software modules for a software
export const loadItemsForSoftware = createAction(
  '[SoftwareModules] Load SoftwareModules for Software',
  props<{ softwareId: string }>()
);

// For Selector component.

export const loadSelectorItems = createAction(
  '[SoftwareModules] Load Software Module Selector Items',
  props<{ forModel: 'software' | 'system' | 'product'; id: string }>()
);
export const loadSelectorItemsSuccess = createAction(
  '[SoftwareModules] Load Software Module Selector Items Success',
  props<{ items: SoftwareModuleListItemDto[] }>()
);
export const loadSelectorItemsError = createAction(
  '[SoftwareModules] Load Software Module Selector Items Error'
);
