import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { SubscriptionType, SubscriptionWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

import {
  SoftwareModuleListDto,
  SoftwareModuleListItemDto,
} from '@softwareModules/dto';

@Component({
  selector: 'subscriptions-create',
  templateUrl: 'subscriptions-create.component.html',
})
export class SubscriptionsCreateComponent
  extends FormComponent
  implements OnInit, OnChanges
{
  @Input() id: string;
  @Input() systemId: string;
  @Input() availableSoftwareModules: SoftwareModuleListItemDto[];

  isSaving$: Observable<boolean>;
  subscriptionTypes: any[];

  selectedModule: SoftwareModuleListDto;
  selectedRecurrence: SubscriptionType;

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._formBuilder.group({
      ...baseForm,
      system: this.systemId,
    });

    this.subscriptionTypes = this.enumToSelectItems(SubscriptionType);
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.form && changes.hasOwnProperty('systemId')) {
      this.form.get('system').patchValue(changes.systemId.currentValue);
    }
  }

  handleSubmit(item: SubscriptionWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }

  handleSoftwareModuleSelection($value) {
    console.log($value);
  }

  handleRecurrenceSelection($value) {
    console.log($value);
  }
}
