import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import {
  SubscriptionType,
  SubscriptionDto,
  SubscriptionWriteDto,
} from '../../dto';
import { baseForm } from '../baseForm';

import {
  actions as softwareModulesActions,
  selectors as softwareModulesSelectors,
} from '@softwareModules/state';
import { SoftwareModuleListItemDto } from '@softwareModules/dto';

@Component({
  selector: 'subscriptions-edit',
  templateUrl: 'subscriptions-edit.component.html',
})
export class SubscriptionsEditComponent
  extends FormComponent
  implements OnInit {
  @Input() id: string;
  @Input() systemId: string;

  item$: Observable<SubscriptionDto>;
  isSaving$: Observable<boolean>;
  softwareModules$: Observable<SoftwareModuleListItemDto[]>;

  subscriptionTypes: any[];

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.item$ = this._store.pipe(select(selectors.selectLoadedItem)).pipe(
      tap((values) =>
        this.form.patchValue({
          ...values,
          softwareModule: {
            id: values.softwareModuleId,
            name: values.softwareModuleName,
          },
        })
      )
    );

    this.softwareModules$ = this._store.pipe(
      select(softwareModulesSelectors.selectItems)
    );

    this.form = this._formBuilder.group({
      ...baseForm,
      notes: [],
    });

    this.subscriptionTypes = this.enumToSelectItems(SubscriptionType);
  }

  handleSubmit(id: string, updatedItem: SubscriptionWriteDto) {
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
