import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { SubscriptionType, SubscriptionWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

import {
  SoftwareModuleListDto,
  SoftwareModuleListItemDto,
} from '@softwareModules/dto';

@Component({
  selector: 'subscriptions-purchase',
  templateUrl: 'subscriptions-purchase.component.html',
})
export class SubscriptionsPurchaseComponent
  extends FormComponent
  implements OnInit, OnChanges
{
  @Input() id: string;
  @Input() systemId: string;
  @Input() availableSoftwareModules: SoftwareModuleListItemDto[];

  isSaving$: Observable<boolean>;
  subscriptionTypes: any[];

  selectedModule: SoftwareModuleListDto;
  selectedRecurrence: SubscriptionType;

  readonly MODAL_CONFIRM_REDIRECTION_ID = 'confirm_redirect_to_paypal';
  readonly MODAL_PURCHASE_FINISHED_ID = 'purchased_from_paypal_finished';

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._formBuilder.group({
      ...baseForm,
      system: this.systemId,
    });

    this.subscriptionTypes = this.enumToSelectItems(SubscriptionType);
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.form && changes.hasOwnProperty('systemId')) {
      this.form.get('system').patchValue(changes.systemId.currentValue);
    }
  }

  handleSubmit(item: SubscriptionWriteDto) {
    this._store.dispatch(
      actions.purchaseGetConfirmationURL({
        item,
        dialogId: this.MODAL_CONFIRM_REDIRECTION_ID,
      })
    );
  }

  handleConfirmRedirectionToPaypal() {
    this._store.dispatch(
      actions.purchaseRedirectToPaypal({
        dialogId: this.MODAL_PURCHASE_FINISHED_ID,
      })
    );
  }

  handlePurchaseFinished() {
    this._store.dispatch(
      actions.purchaseFinished({ url: `/systems/${this.systemId}` })
    );
  }
}
