import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import {
  SubscriptionListItemDto,
  SubscriptionDto,
  SubscriptionWriteDto,
  PaymentConfirmationURL,
} from '../dto';

export const selectItem = createAction(
  '[Subscriptions] Select Subscription',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Subscriptions] Load Subscriptions',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Subscriptions] Load Subscriptions Success',
  props<{ items: SubscriptionListItemDto[] }>()
);
export const loadItemsError = createAction(
  '[Subscriptions] Load Subscriptions Error'
);

export const loadItem = createAction(
  '[Subscriptions] Load Subscription',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Subscriptions] Load Item Success',
  props<{ item: SubscriptionDto }>()
);
export const loadItemError = createAction(
  '[Subscriptions] Load Subscription Error'
);

export const addItem = createAction(
  '[Subscriptions] Add Subscription',
  props<{ item: SubscriptionWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Subscriptions] Added Subscription',
  props<{ item: SubscriptionListItemDto }>()
);
export const addItemError = createAction(
  '[Subscriptions] Add Subscription Error'
);

export const purchaseGetConfirmationURL = createAction(
  '[Subscriptions] Purchase Subscription - Get Confirmation URL',
  props<{ item: SubscriptionWriteDto; dialogId: string }>()
);
export const purchaseGetConfirmationURLSuccess = createAction(
  '[Subscriptions] Purchase Subscription - Received Confirmation URL',
  props<{ data: PaymentConfirmationURL; dialogId: string }>()
);
export const purchaseGetConfirmationURLError = createAction(
  '[Subscriptions] Purchase Subscription - Error getting confirmation URL'
);
export const purchaseRedirectToPaypal = createAction(
  '[Subscriptions] Purchase Subscription - Redirect to Paypal',
  props<{ dialogId: string }>()
);
export const purchaseFinished = createAction(
  '[Subscriptions] Purchase Subscription - Finished',
  props<{ url: string }>()
);

export const updateItem = createAction(
  '[Subscriptions] Update Subscription',
  props<{ id: string; updatedItem: SubscriptionWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Subscriptions] Update Subscription Success',
  props<{ item: Update<SubscriptionListItemDto> }>()
);
export const updateItemError = createAction(
  '[Subscriptions] Update Subscription Error'
);

export const deleteItem = createAction(
  '[Subscriptions] Delete Subscription',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Subscriptions] Delete Subscription Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction(
  '[Subscriptions] Delete Subscription Success'
);

// Related data

// Load subscriptions for a system
export const loadItemsForSystem = createAction(
  '[Subscriptions] Load Subscriptions for System',
  props<{ systemId: string }>()
);
