import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { createEffect, Actions, ofType } from '@ngrx/effects';
import { map, withLatestFrom } from 'rxjs/operators';
import * as actions from './actions';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { actions as notificationActions } from '@shared/notifications';
import { Store } from '@ngrx/store';
import { FEATURE_STATE_NAME } from './reducer';

@Injectable()
export class uiEffects {
  constructor(
    private _actions$: Actions,
    private _router: Router,
    private _store: Store
  ) {}

  closeModalForms$ = createEffect(() =>
    this._actions$.pipe(
      ofType(
        actions.addItemSuccess,
        actions.purchaseGetConfirmationURLSuccess,
        actions.updateItemSuccess
      ),
      map(() => modalFormActions.closeModalForm())
    )
  );

  closeModals$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.deleteItemSuccess),
      map(() => modalActions.closeModal())
    )
  );

  resetModalForm$ = createEffect(() =>
    this._actions$.pipe(
      ofType(
        actions.addItemSuccess,
        actions.purchaseGetConfirmationURLSuccess,
        actions.updateItemSuccess
      ),
      map(() => modalFormActions.resetModalForm())
    )
  );

  getPaymentConfirmationURL$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.purchaseGetConfirmationURLSuccess),
      map(({ data, dialogId }) => {
        return modalActions.openModal({ id: dialogId });
      })
    )
  );

  forwardUserToPaymentConfirmation$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.purchaseRedirectToPaypal),
      withLatestFrom(this._store),
      map(([action, state]) => {
        window.open(state[FEATURE_STATE_NAME].purchaseConfirmationURL);
        return modalActions.openModal({ id: action.dialogId });
    9  })
    )
  );

  purchaseFinished$ = createEffect(
    () =>
      this._actions$.pipe(
        ofType(actions.purchaseFinished),
        map(({ url }) => {
          window.location.href = url;
        })
      ),
    { dispatch: false }
  );

  pushSuccessNotifications$ = createEffect(() =>
    this._actions$.pipe(
      ofType(
        actions.addItemSuccess,
        actions.updateItemSuccess,
        actions.deleteItemSuccess
      ),
      map((action) => {
        let body = '';

        switch (action.type) {
          case actions.addItemSuccess.type:
            body = `Subscription started!`;
            break;

          case actions.updateItemSuccess.type:
            body = `Subscription updated!`;
            break;
          case actions.deleteItemSuccess.type:
            body = 'Subscription canceled!';
            break;
        }

        return notificationActions.push({ item: { level: 'info', body } });
      })
    )
  );
}
