import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { state, modelEffects, uiEffects } from './state';
import { SubscriptionsService } from './subscriptions.service';

import { SubscriptionsCreateComponent } from './components/create/subscriptions-create.component';
import { SubscriptionsDeleteComponent } from './components/delete/subscriptions-delete.component';
import { SubscriptionsEditComponent } from './components/edit/subscriptions-edit.component';
import { SubscriptionsTableComponent } from './components/table/subscriptions-table.component';
import { SubscriptionTypePipe } from './pipes/subscription-type.pipe';

import { AuthModule } from '@auth';
import { ModelSelectorModule } from '@shared/model-selector';
import { SubscriptionsPurchaseComponent } from './components/purchase/subscriptions-purchase.component';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    RouterModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    AuthModule,
    ModelSelectorModule,
  ],
  providers: [SubscriptionsService],
  declarations: [
    SubscriptionsCreateComponent,
    SubscriptionsPurchaseComponent,
    SubscriptionsDeleteComponent,
    SubscriptionsEditComponent,
    SubscriptionsTableComponent,
    SubscriptionTypePipe,
  ],
  exports: [
    SubscriptionsCreateComponent,
    SubscriptionsPurchaseComponent,
    SubscriptionsDeleteComponent,
    SubscriptionsEditComponent,
    SubscriptionsTableComponent,
  ],
})
export class SubscriptionsModule {}
