import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { CRUDService } from '@shared/classes/CRUDService';
import { ConfigService } from '@shared/config';
import {
  PaymentConfirmationURL,
  SubscriptionListItemDto,
  SubscriptionWriteDto,
} from './dto';
import { Observable } from 'rxjs';

@Injectable()
export class SubscriptionsService extends CRUDService<
  SubscriptionListItemDto,
  SubscriptionWriteDto
> {
  constructor(http: HttpClient, config: ConfigService) {
    const endpoint = config.get('apiUrl') + '/subscriptions';
    super(http, endpoint);
  }

  getForSystem(systemId: string): Observable<SubscriptionListItemDto[]> {
    return this.http.get<SubscriptionListItemDto[]>(
      `${this.endpoint}/system/${systemId}`
    );
  }

  purchaseGetConfirmationURL(
    newItem: SubscriptionWriteDto
  ): Observable<PaymentConfirmationURL> {
    return this.http.post<PaymentConfirmationURL>(
      `${this.endpoint}/purchase`,
      newItem
    );
  }
}
