import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { SystemAccountLevelType, SystemAccountWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'system-accounts-create',
  templateUrl: 'system-accounts-create.component.html',
})
export class SystemAccountsCreateComponent
  extends FormComponent
  implements OnInit, OnChanges {
  @Input() id: string;
  @Input() systemId: string;

  isSaving$: Observable<boolean>;

  systemAccountLevels: any[];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._formBuilder.group({
      ...baseForm,
      system: this.systemId,
    });

    this.systemAccountLevels = this.enumToSelectItems(SystemAccountLevelType);
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.form && changes.hasOwnProperty('systemId')) {
      this.form.get('system').patchValue(changes.systemId.currentValue);
    }
  }

  handleSubmit(item: SystemAccountWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
