import { Component, Input, OnInit, OnChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { SystemAccountDto } from '../../dto';

@Component({
  selector: 'system-accounts-table',
  templateUrl: 'system-accounts-table.component.html',
})
export class SystemAccountsTableComponent implements OnInit, OnChanges {
  @Input() systemId: string;

  items$: Observable<SystemAccountDto[]>;
  isLoading$: Observable<boolean>;

  readonly MODAL_CREATE_ID = 'system-accounts_create_form';
  readonly MODAL_DELETE_CONFIRM_ID = 'system-accounts_delete_confirm';

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges() {
    this._store.dispatch(actions.loadItems({ systemId: this.systemId }));
  }

  showCreateForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_CREATE_ID })
    );
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_DELETE_CONFIRM_ID })
    );
  }

  selectItem(id: string) {
    this._store.dispatch(actions.selectItem({ id }));
  }
}
