import { Injectable } from '@angular/core';
import { createEffect, Actions, ofType } from '@ngrx/effects';
import { map } from 'rxjs/operators';
import * as actions from './actions';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { actions as notificationActions } from '@shared/notifications';

@Injectable()
export class uiEffects {
  constructor(private _actions$: Actions) {}

  closeModalForms$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItemSuccess, actions.updateItemSuccess),
      map(() => modalFormActions.closeModalForm())
    )
  );

  closeModals$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.deleteItemSuccess),
      map(() => modalActions.closeModal())
    )
  );

  resetModalForm$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.addItemSuccess, actions.updateItemSuccess),
      map(() => modalFormActions.resetModalForm())
    )
  );

  pushSuccessNotifications$ = createEffect(() =>
    this._actions$.pipe(
      ofType(
        actions.addItemSuccess,
        actions.updateItemSuccess,
        actions.deleteItemSuccess
      ),
      map((action) => {
        let body = '';

        switch (action.type) {
          case actions.addItemSuccess.type:
            body = `System Account registered! A notification email has been sent to the user.`;
            break;
          case actions.updateItemSuccess.type:
            body = `System Account updated!`;
            break;
          case actions.deleteItemSuccess.type:
            body =
              'System Account deleted! A notification email has been sent to the user.';
            break;
        }

        return notificationActions.push({ item: { level: 'info', body } });
      })
    )
  );
}
