import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';
import { ReactiveFormsModule } from '@angular/forms';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { state, modelEffects, uiEffects } from './state';
import { SystemAccountsService } from './systemAccounts.service';

import { SystemAccountsCreateComponent } from './components/create/system-accounts-create.component';
import { SystemAccountsDeleteComponent } from './components/delete/system-accounts-delete.component';
import { SystemAccountsTableComponent } from './components/table/system-accounts-table.component';
import { SystemAccountLevelPipe } from './pipes/system-account-level.pipe';

import { AuthModule } from '@auth';
import { ModelSelectorModule } from '@shared/model-selector';
import { SystemAccountsSimpleTableComponent } from './components/simple-table/system-accounts-simple-table.component';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    RouterModule,
    ReactiveFormsModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    AuthModule,
    ModelSelectorModule,
  ],
  providers: [SystemAccountsService],
  declarations: [
    SystemAccountsCreateComponent,
    SystemAccountsDeleteComponent,
    SystemAccountsTableComponent,
    SystemAccountsSimpleTableComponent,
    SystemAccountLevelPipe,
  ],
  exports: [
    SystemAccountsCreateComponent,
    SystemAccountsDeleteComponent,
    SystemAccountsTableComponent,
    SystemAccountsSimpleTableComponent,
  ],
})
export class SystemAccountsModule {}
