import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { CRUDService } from '@shared/classes/CRUDService';
import { ConfigService } from '@shared/config';
import { ModelTypes, SystemAccountDto, SystemAccountWriteDto } from './dto';
import { Observable } from 'rxjs';

@Injectable()
export class SystemAccountsService extends CRUDService<
  SystemAccountDto,
  SystemAccountWriteDto
> {
  constructor(http: HttpClient, config: ConfigService) {
    const endpoint = config.get('apiUrl') + '/systemAccounts';
    super(http, endpoint);
  }

  getForModel(
    forModel: ModelTypes,
    id: string
  ): Observable<SystemAccountDto[]> {
    return this.http.get<SystemAccountDto[]>(
      `${this.endpoint}/${forModel}/${id}`
    );
  }

  getForSystem(systemId: string): Observable<SystemAccountDto[]> {
    return this.http.get<SystemAccountDto[]>(
      `${this.endpoint}/system/${systemId}`
    );
  }
}
