import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { SystemStatusDto } from '../../dto';

@Component({
  selector: 'systemStatus-table',
  templateUrl: 'systemStatus-table.component.html',
})
export class SystemStatusTableComponent implements OnInit, OnChanges {
  @Input() systemId: string;
  @Input() noTitle: false;

  items$: Observable<SystemStatusDto[]>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('systemId')) {
      const date = new Date().toJSON().slice(0, 10);

      this._store.dispatch(
        actions.loadItems({
          systemId: changes.systemId.currentValue,
          date,
        })
      );
    }
  }
}
