import { Injectable } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { catchError, map, mergeMap } from 'rxjs/operators';
import { of } from 'rxjs';
import * as actions from './actions';
import { SystemStatusDto } from '../dto';
import { SystemStatusService } from '../systemStatus.service';

@Injectable()
export class modelEffects {
  constructor(
    private _actions$: Actions,
    private _crudService: SystemStatusService
  ) {}

  loadItems$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.loadItems),
      mergeMap((action) =>
        this._crudService.getForSystem(action.systemId, action.date).pipe(
          map((items: SystemStatusDto[]) =>
            actions.loadItemsSuccess({ items })
          ),
          catchError(() => of(actions.loadItemsError()))
        )
      )
    )
  );

  loadItemsForAllSystems$ = createEffect(() =>
    this._actions$.pipe(
      ofType(actions.loadItemsForAllSystems),
      mergeMap((action) =>
        this._crudService.getForAllSystems(action.date).pipe(
          map((items: SystemStatusDto[]) =>
            actions.loadItemsSuccess({ items })
          ),
          catchError(() => of(actions.loadItemsError()))
        )
      )
    )
  );
}
