import { EntityState, EntityAdapter, createEntityAdapter } from '@ngrx/entity';
import { createReducer, Action, on } from '@ngrx/store';
import * as actions from './actions';
import { SystemStatusDto } from '../dto';

export const FEATURE_STATE_NAME = 'systemStatus';

export interface State extends EntityState<SystemStatusDto> {
  selectedItemId: string;
  loadingItems: boolean;
}

export const adapter: EntityAdapter<SystemStatusDto> =
  createEntityAdapter<SystemStatusDto>({
    sortComparer: false,
  });

const initialState: State = adapter.getInitialState({
  selectedItemId: null,
  loadingItems: false,
});

const _entityReducer = createReducer(
  initialState,
  on(actions.loadItems, (state) => ({
    ...state,
    loadingItems: true,
  })),
  on(actions.loadItemsSuccess, (state, { items }) =>
    adapter.setAll(items, { ...state, loadingItems: false })
  ),
  on(actions.loadItemsError, (state) => ({ ...state, loadingItems: false }))
);

export function reducer(state: State | undefined, action: Action) {
  return _entityReducer(state, action);
}
