/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * SystemStatus Module
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { state, modelEffects } from './state';
import { SystemStatusService } from './systemStatus.service';
import { SystemStatusTableComponent } from './components/table/systemStatus-table.component';
import { SystemStatusModePipe } from './pipes/systemStatus-mode.pipe';
import { SystemStatusMapComponent } from './components/map/systemStatus-map.component';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects]),
  ],
  providers: [SystemStatusService],
  declarations: [
    SystemStatusTableComponent,
    SystemStatusMapComponent,
    SystemStatusModePipe,
  ],
  exports: [SystemStatusTableComponent, SystemStatusMapComponent],
})
export class SystemStatusModule {}
