import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { baseForm } from '../baseForm';
import { SystemWriteDto } from '../../dto';

@Component({
  selector: 'systems-create',
  templateUrl: 'systems-create.component.html',
})
export class SystemsCreateComponent extends FormComponent implements OnInit {
  @Input() id: string;
  @Input() locationId: string;

  isSaving$: Observable<boolean>;

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));
    this.form = this._formBuilder.group(baseForm);
    this.form.get('location').patchValue(this.locationId);
  }

  handleSubmit(item: SystemWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
