import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { tap } from 'rxjs/operators';
import { Store, select } from '@ngrx/store';
import { FormBuilder } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { actions, selectors } from '../../state';
import { SystemDto, SystemWriteDto } from '../../dto';
import { baseForm } from '../baseForm';

@Component({
  selector: 'systems-edit',
  templateUrl: 'systems-edit.component.html',
})
export class SystemsEditComponent extends FormComponent implements OnInit {
  @Input() id: string;

  isSaving$: Observable<boolean>;
  item$: Observable<SystemDto>;

  productTypes: any[];

  tabItems = [
    { id: 'general', label: 'General' },
    { id: 'details', label: 'Details' },
    { id: 'other', label: 'Other' },
  ];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.item$ = this._store.pipe(select(selectors.selectLoadedItem)).pipe(
      tap((values) =>
        this.form.patchValue({
          ...values,
          product: { value: values?.productId, label: values?.productName },
          location: { id: values?.locationId, name: values?.locationName },
        })
      )
    );

    // Initialize the form.
    this.form = this._formBuilder.group({
      ...baseForm,
      description: [],
      notes: [],
    });
  }

  handleSubmit(id: string, updatedItem: SystemWriteDto) {
    this._store.dispatch(actions.updateItem({ id, updatedItem }));
  }
}
