import { Component, Input, OnInit, OnChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { SystemListItemDto } from '../../dto';

@Component({
  selector: 'systems-table',
  templateUrl: 'systems-table.component.html',
})
export class SystemsTableComponent implements OnInit, OnChanges {
  @Input() locationId: string;

  items$: Observable<SystemListItemDto[]>;
  isLoading$: Observable<boolean>;

  readonly MODAL_CREATE_ID = 'systems_create_form';
  readonly MODAL_DELETE_CONFIRM_ID = 'systems_delete_confirm';

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges() {
    this._store.dispatch(
      actions.loadItemsForModel({ model: 'location', id: this.locationId })
    );
  }

  showCreateForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_CREATE_ID })
    );
  }

  selectLoaction(id: string) {
    this._store.dispatch(actions.selectItem({ id }));
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_DELETE_CONFIRM_ID })
    );
  }
}
