import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { SystemDto } from '../../dto';

@Component({
  selector: 'systems-view',
  templateUrl: 'systems-view.component.html',
})
export class SystemsViewComponent implements OnInit {
  @Input() singlePage: boolean;

  readonly MODAL_EDIT_ID = 'systems_view_edit';
  readonly MODAL_CONFIRM_DELETE_ID = 'systems_view_confirm_delete';
  readonly MODAL_CONFIRM_RESET_SECRET_ID = 'systems_view_confirm_reset_secret';

  item$: Observable<SystemDto>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.item$ = this._store.pipe(select(selectors.selectLoadedItem));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItem));
  }

  showEditForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_EDIT_ID })
    );
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_CONFIRM_DELETE_ID })
    );
  }

  handleDeleteItem(id: string) {
    this._store.dispatch(actions.deleteItem({ id }));
  }

  handleResetSecret() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_CONFIRM_RESET_SECRET_ID })
    );
  }
}
