/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Systems Redux Actions.
 */

import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import {
  ModelTypes,
  SystemListItemDto,
  SystemDto,
  SystemWriteDto,
} from '../dto';

// CRUD actions

export const selectItem = createAction(
  '[Systems] Select System',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Systems] Load Systems',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Systems] Load Systems Success',
  props<{ items: SystemListItemDto[] }>()
);
export const loadItemsError = createAction('[Systems] Load Systems Error');

export const loadItem = createAction(
  '[Systems] Load System',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Systems] Load System Success',
  props<{ item: SystemDto }>()
);
export const loadItemError = createAction('[Systems] Load Item Error');

export const addItem = createAction(
  '[Systems] Add System',
  props<{ item: SystemWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Systems] Added System Success',
  props<{ item: SystemListItemDto }>()
);
export const addItemError = createAction('[Systems] Added System Error');

export const updateItem = createAction(
  '[Systems] Update System',
  props<{ id: string; updatedItem: SystemWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Systems] Update System Success',
  props<{ item: Update<SystemListItemDto> }>()
);
export const updateItemError = createAction('[Systems] Update System Error');

export const deleteItem = createAction(
  '[Systems] Delete System',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Systems] Delete System Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction('[Systems] Delete System Error');

// Actions for filtering in the list

export const searchItems = createAction(
  '[Systems] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[Systems] Order Items',
  props<{ sortOrder: string }>()
);

// Reset Asset Secret
export const resetSecret = createAction(
  '[Systems] Reset Secret',
  props<{ id: string }>()
);
export const resetSecretSuccess = createAction(
  '[Systems] Reset Secret Success',
  props<{ item: SystemListItemDto }>()
);

// Related data

// Load systems for other models
export const loadItemsForModel = createAction(
  '[Systems] Load Systems for Model',
  props<{ model: ModelTypes; id: string }>()
);
