/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Systems Module
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { state, modelEffects, uiEffects } from './state';
import { SystemsService } from './systems.service';
import { SystemsRoutingModule } from './systems-routing.module';

import { SystemsCreateComponent } from './components/create/systems-create.component';
import { SystemsDeleteComponent } from './components/delete/systems-delete.component';
import { SystemsEditComponent } from './components/edit/systems-edit.component';
import { SystemsIndexPage } from './pages/index/systems-index.page';
import { SystemsListComponent } from './components/list/systems-list.component';
import { SystemsListItemComponent } from './components/list-item/systems-list-item.component';
import { SystemsTableComponent } from './components/table/systems-table.component';
import { SystemsSimpleTableComponent } from './components/simple-table/systems-simple-table.component';
import { SystemsViewComponent } from './components/view/systems-view.component';
import { SystemsResetSecretComponent } from './components/reset-secret/systems-reset-secret.component';
import { SystemsViewPage } from './pages/view/systems-view.page';

import { AuthModule } from '@auth/auth.module';
import { ModelSelectorModule } from '@shared/model-selector';
import { SystemAccountsModule } from '@systemAccounts/systemAccounts.module';
import { SubscriptionsModule } from '@subscriptions/subscriptions.module';
import { IssuesModule } from '@issues/issues.module';
import { SystemStatusModule } from '@systemStatus/systemStatus.module';
import { DocumentsModule } from '@shared/documents/documents.module';

import { SystemsActivityComponent } from './components/activity/systems-activity.component';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    RouterModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    //SystemsRoutingModule,
    AuthModule,
    ModelSelectorModule,
    SubscriptionsModule,
    SystemAccountsModule,
    IssuesModule,
    SystemStatusModule,
    DocumentsModule,
  ],
  providers: [SystemsService],
  declarations: [
    SystemsCreateComponent,
    SystemsDeleteComponent,
    SystemsEditComponent,
    SystemsIndexPage,
    SystemsListComponent,
    SystemsListItemComponent,
    SystemsTableComponent,
    SystemsSimpleTableComponent,
    SystemsViewComponent,
    SystemsViewPage,
    SystemsResetSecretComponent,
    SystemsActivityComponent,
  ],
  exports: [
    SystemsCreateComponent,
    SystemsDeleteComponent,
    SystemsEditComponent,
    SystemsIndexPage,
    SystemsTableComponent,
    SystemsSimpleTableComponent,
    SystemsViewPage,
  ],
})
export class SystemsModule {}
