import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CRUDService } from '@shared/classes/CRUDService';
import { ConfigService } from '@shared/config';
import { ModelTypes, SystemListItemDto, SystemWriteDto } from './dto';

@Injectable()
export class SystemsService extends CRUDService<
  SystemListItemDto,
  SystemWriteDto
> {
  constructor(http: HttpClient, config: ConfigService) {
    const endpoint = config.get('apiUrl') + '/systems';
    super(http, endpoint);
  }

  getForModel(
    forModel: ModelTypes,
    id: string
  ): Observable<SystemListItemDto[]> {
    return this.http.get<SystemListItemDto[]>(
      `${this.endpoint}/${forModel}/${id}`
    );
  }

  resetSecret(id: string): Observable<SystemListItemDto> {
    return this.http.post<SystemListItemDto>(
      `${this.endpoint}/${id}/reset-secret`,
      {}
    );
  }
}
