/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Create Component
 */

import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { FormBuilder, Validators } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { baseForm } from '../baseForm';
import {
  UserProfileType,
  UserRoleType,
  UserInnerspecRoleType,
  UserWriteDto,
} from '../../dto';

@Component({
  selector: 'users-create',
  templateUrl: 'users-create.component.html',
})
export class UsersCreateComponent
  extends FormComponent
  implements OnInit, OnChanges
{
  @Input() id: string;
  @Input() locationId: string;
  @Input() isInnerspec: boolean;

  isSaving$: Observable<boolean>;

  roleTypes: any[];

  constructor(private _formBuilder: FormBuilder, private _store: Store) {
    super();
  }

  ngOnInit() {
    this.isSaving$ = this._store.pipe(select(selectors.selectIsSavingItem));

    this.form = this._formBuilder.group({
      ...baseForm,
      location: [this.locationId],
    });

    this.handleProfileChange();
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.hasOwnProperty('locationId') && this.form) {
      this.form.get('location').patchValue(changes.locationId.currentValue);
    }
  }

  handleProfileChange() {
    const types = this.isInnerspec ? UserInnerspecRoleType : UserRoleType;
    this.roleTypes = this.enumToSelectItems(types);
  }

  handleSubmit(item: UserWriteDto) {
    this._store.dispatch(actions.addItem({ item }));
  }
}
