/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users List Component
 */

import { Component, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { UserListItemDto } from '../../dto';

@Component({
  selector: 'users-list',
  templateUrl: 'users-list.component.html',
})
export class UsersListComponent implements OnInit {
  items$: Observable<UserListItemDto[]>;
  selectedItemId$: Observable<string>;
  selectedSortOrder$: Observable<string>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.selectedItemId$ = this._store.pipe(
      select(selectors.selectCurentItemId)
    );
    this.selectedSortOrder$ = this._store.pipe(
      select(selectors.selectSortOrder)
    );
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));

    this._store.dispatch(actions.loadItems({}));
  }

  handleSelectedItem(id: string) {
    this._store.dispatch(actions.selectItem({ id }));
    this._store.dispatch(actions.loadItem({ id }));
  }

  handleSearchChange(text: string) {
    this._store.dispatch(actions.searchItems({ searchText: text }));
  }

  handleOrderItems(sortOrder: string) {
    this._store.dispatch(actions.sortItems({ sortOrder }));
  }
}
