/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Login Component
 */

import { Component, OnInit, Output, EventEmitter, Input } from '@angular/core';
import { FormBuilder, Validators } from '@angular/forms';
import { FormComponent } from '@shared/classes/FormComponent';
import { fadeInAnimation } from '@shared/ui/animations';

@Component({
  selector: 'users-login-form',
  templateUrl: 'users-login-form.component.html',
  styleUrls: ['users-login-form.component.scss'],
  animations: [fadeInAnimation('1000ms')],
})
export class UsersLoginFormComponent extends FormComponent implements OnInit {
  @Input() isBusy: boolean = false;
  @Output() onSubmit = new EventEmitter();

  constructor(private _formBuilder: FormBuilder) {
    super();
  }

  ngOnInit() {
    this.form = this._formBuilder.group({
      email: [, [Validators.required, Validators.email]],
      password: [, [Validators.required]],
    });
  }

  handleSubmit() {
    if (this.form.valid) {
      this.onSubmit.emit(this.form.value);
    }
  }
}
