/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Simple Table Component
 */

import {
  Component,
  Input,
  OnInit,
  OnChanges,
  SimpleChanges,
} from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { ModelTypes, UserListItemDto } from '../../dto';

@Component({
  selector: 'users-simple-table',
  templateUrl: 'users-simple-table.component.html',
})
export class UsersSimpleTableComponent implements OnInit, OnChanges {
  @Input() forModel: ModelTypes;
  @Input() modelId: string;
  @Input() title: string;

  items$: Observable<UserListItemDto[]>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges(changes: SimpleChanges) {
    if (
      changes.hasOwnProperty('forModel') ||
      changes.hasOwnProperty('modelId')
    ) {
      this._store.dispatch(
        actions.loadItemsForModel({
          model: changes.forModel?.currentValue || this.forModel,
          id: changes.modelId?.currentValue || this.modelId,
        })
      );
    }
  }
}
