/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Table Component
 */

import { Component, Input, OnInit, OnChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { UserListItemDto } from '../../dto';
import { getColor } from '../colors';

@Component({
  selector: 'users-table',
  templateUrl: 'users-table.component.html',
})
export class UsersTableComponent implements OnInit, OnChanges {
  @Input() locationId: string;
  @Input() isInnerspec: boolean;
  @Input() showLocation: boolean = false;
  @Input() showCompany: boolean = false;

  items$: Observable<UserListItemDto[]>;
  isLoading$: Observable<boolean>;

  readonly MODAL_CREATE_ID = 'users_create_form';
  readonly MODAL_DELETE_CONFIRM_ID = 'users_delete_confirm';

  constructor(private _store: Store) {}

  ngOnInit() {
    this.items$ = this._store.pipe(select(selectors.selectItems));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItems));
  }

  ngOnChanges() {
    this._store.dispatch(
      actions.loadItemsForModel({ model: 'location', id: this.locationId })
    );
  }

  showCreateForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_CREATE_ID })
    );
  }

  selectUser(id: string) {
    this._store.dispatch(actions.selectItem({ id }));
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_DELETE_CONFIRM_ID })
    );
  }

  getTypeColor(item: UserListItemDto): string {
    return getColor(item.role);
  }
}
