/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users View Component
 */

import { Component, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { Store, select } from '@ngrx/store';
import { actions, selectors } from '../../state';
import { actions as modalFormActions } from '@shared/modal-form';
import { actions as modalActions } from '@shared/modal';
import { UserDto } from '../../dto';

@Component({
  selector: 'users-view',
  templateUrl: 'users-view.component.html',
})
export class UsersViewComponent implements OnInit {
  @Input() singlePage = false;

  readonly MODAL_EDIT_ID = 'users_view_edit';
  readonly MODAL_CONFIRM_DELETE_ID = 'users_view_confirm_delete';

  item$: Observable<UserDto>;
  isLoading$: Observable<boolean>;

  constructor(private _store: Store) {}

  ngOnInit() {
    this.item$ = this._store.pipe(select(selectors.selectLoadedItem));
    this.isLoading$ = this._store.pipe(select(selectors.selectIsLoadingItem));
  }

  getName(item: UserDto): string {
    return item.name || item.email;
  }

  showEditForm() {
    this._store.dispatch(
      modalFormActions.openModalForm({ id: this.MODAL_EDIT_ID })
    );
  }

  showConfirmDelete() {
    this._store.dispatch(
      modalActions.openModal({ id: this.MODAL_CONFIRM_DELETE_ID })
    );
  }

  handleDeleteItem(id: string) {
    this._store.dispatch(actions.deleteItem({ id }));
  }
}
