/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Redux Actions.
 */

import { createAction, props } from '@ngrx/store';
import { Update } from '@ngrx/entity';
import { ModelTypes, UserListItemDto, UserDto, UserWriteDto } from '../dto';

// CRUD actions

export const selectItem = createAction(
  '[Users] Select User',
  props<{ id: string }>()
);

export const loadItems = createAction(
  '[Users] Load Users',
  props<{ searchText?: string }>()
);
export const loadItemsSuccess = createAction(
  '[Users] Load Users Success',
  props<{ items: UserListItemDto[] }>()
);
export const loadItemsError = createAction('[Users] Load Users Error');

export const loadItem = createAction(
  '[Users] Load User',
  props<{ id: string }>()
);
export const loadItemSuccess = createAction(
  '[Users] Load Item Success',
  props<{ item: UserDto }>()
);
export const loadItemError = createAction('[Users] Load Item Error');

export const addItem = createAction(
  '[Users] Add User',
  props<{ item: UserWriteDto }>()
);
export const addItemSuccess = createAction(
  '[Users] Added User Success',
  props<{ item: UserListItemDto }>()
);
export const addItemError = createAction('[Users] Added User Error');

export const updateItem = createAction(
  '[Users] Update User',
  props<{ id: string; updatedItem: UserWriteDto }>()
);
export const updateItemSuccess = createAction(
  '[Users] Update User Success',
  props<{ item: Update<UserListItemDto> }>()
);
export const updateItemError = createAction('[Users] Update User Error');

export const deleteItem = createAction(
  '[Users] Delete User',
  props<{ id: string }>()
);
export const deleteItemSuccess = createAction(
  '[Users] Delete User Success',
  props<{ id: string }>()
);
export const deleteItemError = createAction('[Users] Delete User Error');

export const resetPassword = createAction(
  '[Users] Reset Password',
  props<{ email: string }>()
);
export const resetPasswordSuccess = createAction(
  '[Users] Reset Password Success'
);
export const resetPasswordError = createAction('[Users] Rerset Password Error');

// Actions for filtering in the list

export const searchItems = createAction(
  '[Users] Search Items',
  props<{ searchText?: string }>()
);

export const sortItems = createAction(
  '[Users] Order Items',
  props<{ sortOrder: string }>()
);

// Actions for searching users

export const searchForSelection = createAction(
  '[Users] Search Users for selection',
  props<{ searchText: string }>()
);

export const searchForSelectionSuccess = createAction(
  '[Users] Search Users for selection success',
  props<{ users: UserListItemDto[] }>()
);
export const searchForSelectionError = createAction(
  '[Users] Search Users for selection error'
);

// Related data

// Load issues for other models
export const loadItemsForModel = createAction(
  '[Users] Load Users for Model',
  props<{ model: ModelTypes; id: string }>()
);

// For Selector component.
export const loadSelectorItems = createAction(
  '[Users] Load Users Selector Items',
  props<{ forModel: ModelTypes; id: string }>()
);
export const loadSelectorItemsSuccess = createAction(
  '[Users] Load Users Selector Items Success',
  props<{ items: UserListItemDto[] }>()
);
export const loadSelectorItemsError = createAction(
  '[Users] Load Users Selector Items Error'
);
