/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Routing Module
 */

import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { UsersIndexPage } from './pages/index/users-index.page';
import { UsersViewPage } from './pages/view/users-view.page';
import { UsersLoginPage } from './pages/login/users-login.page';
import { UsersResetPasswordPage } from './pages/reset-password/users-reset-password.page';
import { UserResolver } from './resolvers/user.resolver';

import { AuthPrivate } from '@auth/guards/auth-private.guard';
import { AuthPublic } from '@auth/guards/auth-public.guard';

const routes: Routes = [
  // Public paths, only available if the user is
  // not logged in.
  {
    path: 'login',
    component: UsersLoginPage,
    canActivate: [AuthPublic],
  },
  {
    path: 'reset-password',
    component: UsersResetPasswordPage,
    canActivate: [AuthPublic],
  },
  // Private paths.
  {
    path: '',
    canActivate: [AuthPrivate],
    children: [
      {
        path: ':id',
        component: UsersViewPage,
        resolve: { location: UserResolver },
      },
      { path: '', component: UsersIndexPage, pathMatch: 'full' },
    ],
  },
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class UsersRoutingModule {}
