/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Module
 */

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { UiModule } from '@shared/ui/ui.module';
import { ModalModule } from '@shared/modal/modal.module';
import { ModalFormModule } from '@shared/modal-form';

import { state, modelEffects, uiEffects } from './state';
import { UsersService } from './users.service';

import { UsersCreateComponent } from './components/create/users-create.component';
import { UsersEditComponent } from './components/edit/users-edit.component';
import { UsersDeleteComponent } from './components/delete/users-delete.component';
import { UsersListComponent } from './components/list/users-list.component';
import { UsersListItemComponent } from './components/list-item/users-list-item.component';
import { UsersViewComponent } from './components/view/users-view.component';

import { UsersIndexPage } from './pages/index/users-index.page';
import { UsersViewPage } from './pages/view/users-view.page';

import { UserProfileTypePipe } from './pipes/profileType.pipe';
import { UserRoleTypePipe } from './pipes/roleType.pipe';
import { UsersTableComponent } from './components/table/users-table.component';
import { UsersSimpleTableComponent } from './components/simple-table/users-simple-table.component';
import { UsersLoginPage } from './pages/login/users-login.page';
import { UsersResetPasswordPage } from './pages/reset-password/users-reset-password.page';
import { UsersLoginFormComponent } from './components/login-form/users-login-form.component';
import { UsersResetPasswordFormComponent } from './components/reset-password-form/users-reset-password-form.component';

import { AuthModule } from '@auth';
import { ModelSelectorModule } from '@shared/model-selector';
import { IssuesModule } from '@issues/issues.module';
import { SystemAccountsModule } from '@systemAccounts/systemAccounts.module';

@NgModule({
  imports: [
    CommonModule,
    UiModule,
    ReactiveFormsModule,
    RouterModule,
    ModalModule,
    ModalFormModule,
    StoreModule.forFeature(state.FEATURE_STATE_NAME, state.reducer),
    EffectsModule.forFeature([modelEffects, uiEffects]),
    AuthModule,
    ModelSelectorModule,
    IssuesModule,
    SystemAccountsModule,
  ],
  providers: [UsersService],
  declarations: [
    UserProfileTypePipe,
    UserRoleTypePipe,
    UsersCreateComponent,
    UsersDeleteComponent,
    UsersEditComponent,
    UsersIndexPage,
    UsersListComponent,
    UsersListItemComponent,
    UsersViewComponent,
    UsersViewPage,
    UsersTableComponent,
    UsersSimpleTableComponent,
    UsersLoginPage,
    UsersResetPasswordPage,
    UsersLoginFormComponent,
    UsersResetPasswordFormComponent,
  ],
  exports: [
    UsersCreateComponent,
    UsersDeleteComponent,
    UsersEditComponent,
    UsersIndexPage,
    UsersViewPage,
    UsersTableComponent,
    UsersSimpleTableComponent,
  ],
})
export class UsersModule {}
