/**
 * NDT-Link Client.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Users Service
 */

import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { CRUDService } from '@shared/classes/CRUDService';
import { ConfigService } from '@shared/config';
import { ModelTypes, UserListItemDto, UserWriteDto } from './dto';
import { Observable } from 'rxjs';

@Injectable()
export class UsersService extends CRUDService<UserListItemDto, UserWriteDto> {
  constructor(http: HttpClient, config: ConfigService) {
    const endpoint = config.get('apiUrl') + '/users';
    super(http, endpoint);
  }

  getForModel(forModel: ModelTypes, id: string): Observable<UserListItemDto[]> {
    return this.http.get<UserListItemDto[]>(
      `${this.endpoint}/${forModel}/${id}`
    );
  }

  update(id: string, data: UserWriteDto): Observable<any> {
    const formData = new FormData();

    // The form calling this method has a file input. In order for
    // the backend to properly process it, we need to pass the form
    // content as a formData object.
    Object.keys(data).forEach(
      (key) => data[key] && formData.append(key, data[key])
    );

    return this.http.patch(`${this.endpoint}/${id}`, formData);
  }

  resetPassword(email: string): Observable<any> {
    return this.http.post(`${this.endpoint}/resetPassword`, { email });
  }
}
