# NDT-Link Back-End

This application is made with [NestJS](https://nestjs.com/) framework and [TypeORM](https://typeorm.io/) for database operations. It also uses _Data Transfer Objects_ (DTO) in order to filter data sent in responses to the front-end and in the body of incoming requests from the front-end for creation, edition and update of content in the database.

The application also uses the following packages:

1. [NestJSX CRUD](https://github.com/nestjsx/crud), provides boiler plate for quick development of CRUD controllers and services, which tend to be very repetitive.
1. [Class Transformer](https://github.com/typestack/class-transformer) for mapping database entity data to DTOs.
1. [Class Validator](https://github.com/typestack/class-validator) for validating body content sent by the front-end for `POST`, `PUT` and `PATCH` requests.
1. [Helmet](https://github.com/helmetjs/helmet) and [Express Rate Limit](https://www.npmjs.com/package/express-rate-limit) for basic security measures.
1. [Passport](http://www.passportjs.org/) and [Passport JWT](http://www.passportjs.org/packages/passport-jwt/) for authentication and authorization with local strategy (username and password based).

For authentication and authorization, this application uses [JSON Web Tokens (JWT)](https://jwt.io/), issued during the login process. The front-end needs to send the issued token in each HTTP request in the `Authorization` header as a `Bearer` token.

## Instructions

Install all dependencies:

`npm install`

To start the application in development mode, run the following command:

`npm run start:dev`

To build the application, run the following command:

`npm run build`

The final compiled JS files that compose the application will be available in the folder `dist` which then can be uploaded to the server.

## Configuration

The application uses default values for several parameters which can be overridden with the following environmental variables that need to be set before starting the application.

1. `APP_PORT`: Port where the application will be listening from for incoming connections.
1. `APP_ADMIN_EMAIL`: Email (username) used to create the superuser when populating the database for the first time.
1. `APP_ADMIN_PASSWORD`: Password to assign to the superuser.
1. `DB_SERVER`: URL to the MySQL database server.
1. `DB_PORT`: Port of the MySQL database server.
1. `DB_NAME`: Name of the database.
1. `DB_USER`: User used for full access to the database.
1. `DB_PASSWORD`: Password for the database user.
1. `JWT_SECRET`: text used to encode the JWT tokens (make sure it's something complicated).

--------

**This document is still under work and will continue growing as more functionality is added in the application.**
