import { Exclude, Expose } from 'class-transformer';
import { IsNotEmpty, IsOptional, Length, MinLength } from 'class-validator';

@Exclude()
export class AddressDto {
  @Expose()
  id: string;

  @Expose()
  isBilling: boolean;

  @Expose()
  street: string;

  @Expose()
  street2: string;

  @Expose()
  city: string;

  @Expose()
  zip: string;

  @Expose()
  state: string;

  @Expose()
  country: string;

  @Expose()
  phone?: string;

  @Expose()
  notes: string;

  @Expose()
  created: string;

  @Expose()
  updated: string;
}

export class AddressCreateDto {
  @IsNotEmpty()
  isBilling: boolean;

  @IsNotEmpty()
  @Length(3, 150)
  street: string;

  @IsOptional()
  street2?: string;

  @IsNotEmpty()
  city: string;

  @IsNotEmpty()
  @MinLength(4)
  zip: string;

  @IsNotEmpty()
  state: string;

  @IsOptional()
  phone?: string;
}
