/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Application Module.
 */

import { Module } from '@nestjs/common';
import { ConfigModule } from '@nestjs/config';
import { APP_FILTER } from '@nestjs/core';
import 'reflect-metadata';

import { AppService } from './app.service';

import {
  PersistenceModule,
  PersistenceHttpErrorFilter,
} from '@shared/persistence';
import { AuthModule } from './auth';
import configuration from './config';

import { CompaniesModule } from './companies/companies.module';
import { LocationsModule } from './locations/locations.module';
import { AddressesModule } from './addresses';
import { UsersModule } from './users/users.module';
import { SoftwareModule } from './software/software.module';
import { SoftwareModulesModule } from './softwareModules/softwareModules.module';
import { ProductsModule } from './products/products.module';
import { SystemsModule } from './systems/systems.module';
import { SystemAccountsModule } from './systemAccounts/systemAccounts.module';
import { SystemStatusModule } from './systemStatus/systemStatus.module';
import { SubscriptionsModule } from './subscriptions/subscriptions.module';
import { IssuesModule } from './issues/issues.module';
import { IssueCommentsModule } from './issueComments/issueComments.module';
import { DocumentsModule } from './documents/documents.module';
import { AppController } from './app.controller';

@Module({
  imports: [
    ConfigModule.forRoot({ isGlobal: true, load: [configuration] }),
    PersistenceModule,
    AuthModule,
    CompaniesModule,
    LocationsModule,
    AddressesModule,
    UsersModule,
    SoftwareModule,
    SoftwareModulesModule,
    ProductsModule,
    SystemsModule,
    SystemAccountsModule,
    SystemStatusModule,
    SubscriptionsModule,
    IssuesModule,
    IssueCommentsModule,
    DocumentsModule,
  ],
  providers: [
    AppService,
    // Error handling (Exception filters)
    {
      provide: APP_FILTER,
      useClass: PersistenceHttpErrorFilter,
    },
  ],
  controllers: [AppController],
})
export class AppModule {}
