/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Auth Controller
 */

import {
  Controller,
  Request,
  Post,
  UseGuards,
  Query,
  Body,
} from '@nestjs/common';
import { ApiTags } from '@nestjs/swagger';
import { AuthService } from './auth.service';
import { AuthPublic } from './decorators/auth-public.decorator';
import { AuthGuard } from '@nestjs/passport';

@ApiTags('Authentication')
@Controller('auth')
export class AuthController {
  constructor(private authService: AuthService) {}

  @AuthPublic()
  @UseGuards(AuthGuard('localUser')) // Extracts user data after login
  @Post('/login')
  async login(@Request() req) {
    return this.authService.login(req.user);
  }

  @AuthPublic()
  @UseGuards(AuthGuard('localSystem')) // Extracts system data after login
  @Post('/login/system')
  async loginSystem(@Request() req) {
    return this.authService.loginSystem(req.user);
  }

  @AuthPublic()
  @Post('/logout')
  async logout(@Body('id') id: string) {
    return this.authService.logout(id);
  }
}
