/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Auth Module
 */

import { Module } from '@nestjs/common';
import { APP_GUARD } from '@nestjs/core';
import { PassportModule } from '@nestjs/passport';
import { TypeOrmModule } from '@nestjs/typeorm';
import { JwtModule } from '@nestjs/jwt';
import { ConfigService } from '@nestjs/config';
import { AuthService } from './auth.service';

import { LocalStrategy } from './strategies/local.strategy';
import { LocalSystemStrategy } from './strategies/local-system.strategy';

import { JwtStrategy } from './strategies/jwt.strategy';
import { AuthController } from './auth.controller';
import { AuthJwtGuard } from './guards/auth-jwt.guard';

import { User, System, Session } from '@shared/domain';

import { AuthCurrentUser } from './auth-current-user';

@Module({
  imports: [
    TypeOrmModule.forFeature([User, System, Session]),
    PassportModule,
    // Import JWT module passing global configuration
    JwtModule.registerAsync({
      useFactory: (configService: ConfigService) => configService.get('jwt'),
      inject: [ConfigService],
    }),
  ],
  providers: [
    AuthService,
    LocalStrategy,
    LocalSystemStrategy,
    // Provide JwtStrategy passing global configuration
    {
      provide: JwtStrategy,
      useFactory: (configService: ConfigService) =>
        new JwtStrategy(configService.get('jwt')),
      inject: [ConfigService],
    },
    { provide: APP_GUARD, useClass: AuthJwtGuard },
    AuthCurrentUser,
  ],
  exports: [AuthCurrentUser],
  controllers: [AuthController],
})
export class AuthModule {}
