/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * AuthJwt Guard
 */

import { ExecutionContext, Injectable } from '@nestjs/common';
import { Reflector } from '@nestjs/core';
import { AuthGuard } from '@nestjs/passport';
import {
  AUTH_IS_PUBLIC_KEY,
  AUTH_IS_STAFF,
  AUTH_IS_USER,
  AUTH_IS_SYSTEM,
} from '../decorators';
import { AuthUserDataDto, AuthSystemDataDto } from '../auth.dto';

@Injectable()
export class AuthJwtGuard extends AuthGuard('jwt') {
  constructor(private reflector: Reflector) {
    super();
  }

  canActivate(context: ExecutionContext) {
    const user:
      | AuthUserDataDto
      | AuthSystemDataDto = context.switchToHttp().getRequest().user;

    const isPublic = this.reflector.getAllAndOverride<boolean>(
      AUTH_IS_PUBLIC_KEY,
      [context.getHandler(), context.getClass()],
    );

    const isUser = this.reflector.getAllAndOverride<boolean>(AUTH_IS_USER, [
      context.getHandler(),
      context.getClass(),
    ]);

    const isStaff = this.reflector.getAllAndOverride<boolean>(AUTH_IS_STAFF, [
      context.getHandler(),
      context.getClass(),
    ]);

    const isSystem = this.reflector.getAllAndOverride<boolean>(AUTH_IS_SYSTEM, [
      context.getHandler(),
      context.getClass(),
    ]);

    if (isPublic) {
      return true;
    }

    if (user instanceof AuthUserDataDto) {
      if (isUser && user.profile === 'user') {
        return true;
      }

      if (isStaff && user.profile === 'staff') {
        return true;
      }
    }

    if (user instanceof AuthSystemDataDto) {
      if (isSystem) {
        return true;
      }
    }

    return super.canActivate(context);
  }
}
