/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Jwt Strategy
 */

import { Injectable } from '@nestjs/common';
import { ExtractJwt, Strategy } from 'passport-jwt';
import { PassportStrategy } from '@nestjs/passport';

@Injectable()
export class JwtStrategy extends PassportStrategy(Strategy) {
  constructor(options: any) {
    super({
      jwtFromRequest: ExtractJwt.fromAuthHeaderAsBearerToken(),
      ignoreExpiration: options.ignoreExpiration,
      secretOrKey: options.secret,
    });
  }

  async validate(payload: any) {
    // In case of a system, the tag will be in the payload.
    if (payload.tag) {
      return { id: payload.id, tag: payload.tag };
    }

    // In case of a user, the email will be in the payload.
    const { id, email, name, companyId, locationId, profile, role } = payload;
    return { id, email, name, companyId, locationId, profile, role };
  }
}
