/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Local System Strategy
 */

import { Injectable } from '@nestjs/common';
import { PassportStrategy } from '@nestjs/passport';
import { Strategy } from 'passport-local';
import { plainToClass } from 'class-transformer';
import { AuthService } from '../auth.service';
import { AuthSystemDataDto } from '../auth.dto';
import { Product } from '@shared/domain';

// This strategy verifies a system with the given asset tag and password
// and puts its data into the request context.
@Injectable()
export class LocalSystemStrategy extends PassportStrategy(
  Strategy,
  'localSystem',
) {
  constructor(private authService: AuthService) {
    super({
      usernameField: 'tag',
    });
  }

  async validate(tag: string, password: string): Promise<AuthSystemDataDto> {
    const system = await this.authService.validateSystem(tag, password);
    const product = await system.product;
    const location = await system.location;
    const company = await location.company;

    return plainToClass(AuthSystemDataDto, {
      ...system,
      pn: product.pn,
      name: product.name,
      type: product.type,
      locationName: location.name,
      companyName: company.name,
    });
  }
}
