/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Local Strategy
 */

import { Injectable } from '@nestjs/common';
import { Strategy } from 'passport-local';
import { PassportStrategy } from '@nestjs/passport';
import { plainToClass } from 'class-transformer';
import { AuthService } from '../auth.service';
import { AuthUserDataDto } from '../auth.dto';
import { AuthCurrentUser } from '../auth-current-user';

// This strategy verifies a user with the given username and password
// and puts its data into the request context.
@Injectable()
export class LocalStrategy extends PassportStrategy(Strategy, 'localUser') {
  constructor(
    private authService: AuthService,
    private authCurrentUser: AuthCurrentUser,
  ) {
    super({
      usernameField: 'email',
    });
  }

  async validate(email: string, password: string): Promise<AuthUserDataDto> {
    const user = await this.authService.validateUser(email, password);
    const location = await user.location;
    const company = await location.company;

    const flatUser = plainToClass(AuthUserDataDto, user);
    flatUser.companyId = company.id;
    flatUser.locationId = location.id;

    // Store the current user so TypeOrm can access to it
    // from subscribers
    this.authCurrentUser.user = flatUser;

    return flatUser;
  }
}
