/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Companies Controller
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Query,
  UploadedFile,
  UseInterceptors,
} from '@nestjs/common';
import { CompaniesService } from './companies.service';
import { CompanyCreateDto } from './companies.dto';
import { ApiTags } from '@nestjs/swagger';
import { FileInterceptor } from '@nestjs/platform-express';

@ApiTags('Companies')
@Controller('companies')
export class CompaniesController {
  constructor(public service: CompaniesService) {}

  @Get('withTotals')
  getManyWithTotals(
    @Query('search') search: string,
    @Query('order') order: string,
  ) {
    return this.service.find(search, order);
  }

  @Get('count')
  getCount() {
    return this.service.count();
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Post()
  create(@Body() item: CompanyCreateDto) {
    return this.service.addOne(item);
  }

  @Patch(':id')
  @UseInterceptors(FileInterceptor('file'))
  update(
    @Param('id') id: string,
    @Body() changes: CompanyCreateDto,
    @UploadedFile() file: Express.Multer.File,
  ) {
    // If there is no image sent, omit it from the update.
    const data = { ...changes };
    if (file) {
      data.logo = file.filename;
    }

    return this.service.updateOne(id, data);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
