/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Configuration for the application.
 * It pulls values from environmental variables if they are available.
 */

import { isProduction } from '@shared/infrastructure';

const config = () => ({
  site: {
    name: 'NDT-Link',
    description: 'NDT-Link API',
    // URL from where the application will be listening.
    url: isProduction() ? 'https://api.ndt-link.com' : 'http://localhost',
    port: +process.env.PORT || 3000,
    // Credentials for the superuser created by the seeder.
    superEmail: process.env.APP_ADMIN_EMAIL || 'admin@innerspec.com',
    superPassword: process.env.APP_ADMIN_PASSWORD || 'SomePassword',
  },
  client: {
    // URL where the front-end is hosted, used for CORS.
    url: isProduction() ? 'https://www.ndt-link.com' : 'http://localhost:4200',
  },
  // Credentials for the MySQL server.
  database: {
    server: process.env.DB_SERVER || 'localhost',
    port: +process.env.DB_PORT || 3306,
    name: process.env.DB_NAME || 'ndtlink_nest',
    user: process.env.DB_USER || 'dbusername',
    password: process.env.DB_PASSWORD || 'dbpassword',
  },
  data: {
    // Id to assign to Innerspec Technology company when created, so
    // it can be easily identified by other content.
    innerspecCompanyId: '00000000-0000-0000-0000-000000000000',
    // Email address where to send emails from the helpdesk.
    // i.e: support@innerspec.com
    helpdeskEmail: process.env.HELPDESK_MAIL || 'somewhere@someserver.com',
    helpEmail: process.env.CONTACT_EMAIL || 'help@ndt-link.com',
  },
  // Configuration for JSON Web Tokens used for authentication.
  jwt: {
    secret: process.env.JWT_SECRET || 'SomethingReallySuperWeird',
    signOptions: {
      // All tokens will expire one hour after they are issued.
      expiresIn: process.env.JWT_DURATION || '3600s',
    },
    ignoreExpiration: false,
  },
  // Amazon Web Services
  // Simple Email Service
  awsSes: {
    // The credentials should be the ones for a IAM user, not SMTP credentials,
    // otherwise it won't work.
    accessKeyId: process.env.AWS_SES_ACCESS_KEY_ID || 'ENTE YOUR KEY HERE',
    secretAccessKey:
      process.env.AWS_SES_SECRET_ACCESS_KEY ||
      'ENTER YOUR SECRET HERE',
    region: process.env.AWS_SES_REGION || 'us-east-1',
  },
  // Payment Gateway.
  // Current option is Paypal.
  payment: {
    mode: isProduction() ? 'live' : 'sandbox',
    user:
      process.env.PAYMENT_USER ||
      'ENTER YOUR USER HERE',
    password:
      process.env.PAYMENT_ACCOUNT ||
      'ENTER YOU PASSWORD HERE',
  },
});

export default config;
