import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Post,
  Res,
  UploadedFile,
  UseInterceptors,
} from '@nestjs/common';
import { FileInterceptor } from '@nestjs/platform-express';
import { Response } from 'express';
import { ApiTags } from '@nestjs/swagger';
import { DocumentsService } from './documents.service';
import { DocumentCreateDto } from './documents.dto';

@ApiTags('Documents')
@Controller('documents')
export class DocumentsController {
  constructor(private _service: DocumentsService) {}

  @Get(':id')
  download(@Param('id') id: string, @Res() res: Response) {
    return this._service.download(id, res);
  }

  @Get('entity/:entityId')
  findForEntity(@Param('entityId') entityId: string) {
    return this._service.findForEntity(entityId);
  }

  @Post()
  @UseInterceptors(FileInterceptor('file'))
  upload(
    @UploadedFile() file: Express.Multer.File,
    @Body() item: DocumentCreateDto,
  ) {
    return this._service.upload(file.filename, file.originalname, item);
  }

  @Delete(':id')
  delete(@Param('id') id: string) {
    return this._service.deleteOne(id);
  }
}
