/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * DTOs for Documents.
 */

import { Exclude, Expose } from 'class-transformer';
import { IsNotEmpty, IsOptional, MaxLength, IsEnum } from 'class-validator';
import { DocumentType } from '@shared/domain';

/**
 * DTO for each item for the List View in the front-end.
 */
@Exclude()
export class DocumentDto {
  @Expose()
  id: string;

  @Expose()
  name: string;

  @Expose()
  type: string;

  @Expose()
  description: string;

  @Expose()
  originalName: string;

  @Expose()
  entity: string;

  @Expose()
  created: string;

  @Expose()
  updated: string;
}

/**
 * DTO for creation and update using data sent from the front-end.
 * Includes decorators for validation.
 */
export class DocumentCreateDto {
  @IsNotEmpty()
  @IsEnum(DocumentType)
  type: string;

  @IsNotEmpty()
  @MaxLength(150)
  description: string;

  @IsNotEmpty()
  entity: string;
}
