import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { Response } from 'express';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { plainToClass } from 'class-transformer';
import * as fs from 'fs';
import { join } from 'path';
import { BaseEntity, Document } from '@shared/domain';
import { DocumentDto, DocumentCreateDto } from './documents.dto';

@Injectable()
export class DocumentsService {
  constructor(
    @InjectRepository(Document) public repo: Repository<Document>,
    @InjectRepository(BaseEntity) public entityRepo: Repository<BaseEntity>,
  ) {}

  async findForEntity(entityId: string): Promise<DocumentDto[]> {
    const items: any[] = await this.repo.query(
      `
      SELECT 
      document.* 
      FROM document
      WHERE document.entity = ?
      ORDER BY id ASC
      `,
      [entityId],
    );
    return plainToClass(DocumentDto, items);
  }

  async download(id: string, res: Response): Promise<any> {
    const foundItem = await this.repo.findOne(id);

    if (!foundItem) {
      throw new HttpException(
        `Download document failed. Document with ID ${id} was not found`,
        HttpStatus.NOT_FOUND,
      );
    }

    const path = join(__dirname, '..', '..', 'upload/documents');
    const headers = {
      'Content-Type': 'application/pdf',
      'Content-Disposition': `attachment; filename="${foundItem.originalName}"`,
    };

    return res.sendFile(foundItem.filename, { root: path, headers });
  }

  async upload(
    filename: string,
    originalName: string,
    item: DocumentCreateDto,
  ): Promise<DocumentDto> {
    const newItem = Object.assign(new Document(), item);

    newItem.filename = filename;
    newItem.originalName = originalName;

    const addedItem = await this.repo.save(newItem);
    const foundItem = await this.repo.findOne(addedItem.id);
    return plainToClass(DocumentDto, foundItem);
  }

  async deleteOne(id: string): Promise<any> {
    const foundItem = await this.repo.findOne(id);

    if (foundItem) {
      const deleted = await this.repo.delete(id);

      if (deleted) {
        this.deleteFile(foundItem);
      }

      return deleted;
    }

    throw new HttpException(
      `Delete document faild. Document with ID ${id} was not found`,
      HttpStatus.NOT_FOUND,
    );
  }

  deleteFile(item: Document) {
    const path = join(__dirname, '..', '..', 'upload/documents');
    fs.unlinkSync(`${path}/${item.filename}`);
  }
}
