/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Issue Comments Controller
 *
 * Handles routes for Issue Comments.
 */

import { Body, Controller, Delete, Get, Param, Post } from '@nestjs/common';
import { IssueCommentsService } from './issueComments.service';
import { IssueCommentCreateDto } from './issueComments.dto';
import { ApiTags } from '@nestjs/swagger';

@ApiTags('IssueComments')
@Controller('issueComments')
export class IssueCommentsController {
  constructor(public service: IssueCommentsService) {}

  @Get('issue/:issueId')
  getOne(@Param('issueId') issueId: string) {
    return this.service.find(issueId);
  }

  @Post()
  create(@Body() item: IssueCommentCreateDto) {
    return this.service.addOne(item);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
