/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Issues Controller
 *
 * Handles routes for Issues.
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  ParseBoolPipe,
  Patch,
  Post,
  Query,
} from '@nestjs/common';
import { IssuesService } from './issues.service';
import { IssueCreateDto } from './issues.dto';
import { ApiTags } from '@nestjs/swagger';

@ApiTags('Issues')
@Controller('issues')
export class IssuesController {
  constructor(public service: IssuesService) {}

  @Get('withTotals')
  getManyWithTotals(
    @Query('search') search: string,
    @Query('order') order: string,
    @Query('countOnly', ParseBoolPipe) countOnly: boolean,
  ) {
    return this.service.find(search, order, countOnly);
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Get('dashboard/:id')
  getForDashboard() {
    return this.service.findforDashboard();
  }

  @Get('company/:companyId')
  getForCompany(
    @Param('companyId') companyId: string,
    @Query('countOnly', ParseBoolPipe) countOnly: boolean,
  ) {
    return this.service.findForCompany(companyId, countOnly);
  }

  @Get('location/:locationId')
  getForLocation(
    @Param('locationId') locationId: string,
    @Query('countOnly', ParseBoolPipe) countOnly: boolean,
  ) {
    return this.service.findForLocation(locationId, countOnly);
  }

  @Get('user/:userId')
  getForUser(
    @Param('userId') userId: string,
    @Query('countOnly', ParseBoolPipe) countOnly: boolean,
  ) {
    return this.service.findForUser(userId, countOnly);
  }

  @Get('system/:systemId')
  getForSystem(
    @Param('systemId') systemId: string,
    @Query('countOnly', ParseBoolPipe) countOnly: boolean,
  ) {
    return this.service.findForSystem(systemId, countOnly);
  }

  @Post()
  create(@Body() item: IssueCreateDto) {
    return this.service.addOne(item);
  }

  @Patch(':id')
  update(@Param('id') id: string, @Body() changes: IssueCreateDto) {
    return this.service.updateOne(id, changes);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
