/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Userss Controller
 *
 * Handles routes for Users.
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Query,
} from '@nestjs/common';
import { LocationsService } from './locations.service';
import { LocationCreateDto, LocationUpdateDto } from './locations.dto';
import { ApiTags } from '@nestjs/swagger';

@ApiTags('Locations')
@Controller('locations')
export class LocationsController {
  constructor(public service: LocationsService) {}

  @Get('withTotals')
  getManyWithTotals(
    @Query('search') search: string,
    @Query('order') order: string,
  ) {
    return this.service.find(search, order);
  }

  @Get('count')
  getCount() {
    return this.service.count();
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Get('company/:companyId')
  getForCompany(@Param('companyId') companyId: string) {
    return this.service.findForCompany(companyId);
  }

  @Post()
  create(@Body() item: LocationCreateDto) {
    return this.service.addOne(item);
  }

  @Patch(':id')
  update(@Param('id') id: string, @Body() changes: LocationUpdateDto) {
    return this.service.updateOne(id, changes);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
