/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Products Controller
 *
 * Handles routes for Products.
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Query,
  UploadedFile,
  UseInterceptors,
} from '@nestjs/common';
import { ProductsService } from './products.service';
import { ProductCreateDto } from './products.dto';
import { ApiTags } from '@nestjs/swagger';
import { FileInterceptor } from '@nestjs/platform-express';

@ApiTags('Products')
@Controller('products')
export class ProductsController {
  constructor(public service: ProductsService) {}

  @Get('withTotals')
  getManyWithTotals(
    @Query('search') search: string,
    @Query('order') order: string,
  ) {
    return this.service.find(search, order);
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Post()
  create(@Body() item: ProductCreateDto) {
    return this.service.addOne(item);
  }

  @Patch(':id')
  @UseInterceptors(FileInterceptor('file'))
  update(
    @Param('id') id: string,
    @Body() changes: ProductCreateDto,
    @UploadedFile() file: Express.Multer.File,
  ) {
    // If there is no image sent, omit it from the update.
    const data = { ...changes };
    if (file) {
      data.image = file.filename;
    }

    return this.service.updateOne(id, data);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
