/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Base Entity
 */

import {
  Column,
  PrimaryGeneratedColumn,
  CreateDateColumn,
  UpdateDateColumn,
  VersionColumn,
  Entity,
} from 'typeorm';

// Removes leading, middle and trailing spaces.
export const spaceRemover = () => ({
  to: (value: string) => {
    if (value && value.trim) {
      return value
        .trim()
        .split(' ')
        .filter((s) => s !== '')
        .join(' ');
    }
  },
  from: (value: string) => value,
});

@Entity()
export class BaseEntity {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({ nullable: true, transformer: spaceRemover() })
  description?: string;

  @Column({ default: true })
  isActive: boolean;

  @CreateDateColumn()
  created: string;

  @UpdateDateColumn()
  updated: string;

  @Column({ nullable: true })
  notes: string;

  @VersionColumn({ transformer: spaceRemover() })
  version: string;

  // We don't use relations for these columns because User entity
  // extends from BaseEntity too, and TypeORM has many issues handeling
  // circular dependencies between entities. For keeping track of the
  // author and last person to update an entity, we store the user's ID
  // as a string, and handle the queries manually.
  @Column({ nullable: true })
  authorId: string;

  @Column({ nullable: true })
  updatedById: string;
}
