/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Company Entity
 */

import { Entity, Column, OneToMany } from 'typeorm';
import { BaseEntity, spaceRemover } from './base.entity';
import { Location } from './location.entity';

export enum CompanyType {
  CUSTOMER = 'customer',
  REPRESENTATIVE = 'representative',
  PARTNER = 'partner',
  OTHER = 'other',
}

export enum CompanyIndustry {
  AEROSPACE = 'aerospace',
  AUTOMOTIVE = 'automotive',
  FLAT_PRODUCTS = 'flat_products',
  LONG_PRODUCTS = 'long_products',
  NUCLEAR = 'nuclear',
  RAILROAD = 'railroad',
  OIL_GAS = 'oil_gas',
  OTHER = 'other',
}

@Entity()
export class Company extends BaseEntity {
  @Column({ unique: true, transformer: spaceRemover() })
  name: string;

  @Column({ type: 'enum', enum: CompanyType, default: CompanyType.CUSTOMER })
  type: CompanyType;

  @Column({
    type: 'enum',
    enum: CompanyIndustry,
    default: CompanyIndustry.OTHER,
  })
  industry: CompanyIndustry;

  @Column({ default: false })
  isInnerspec: boolean;

  @Column({ nullable: true })
  web?: string;

  @Column({ nullable: true })
  logo?: string;

  @Column()
  isSystem: boolean;

  @OneToMany(() => Location, (location) => location.company)
  locations: Promise<Location[]>;
}
