/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Document Entity
 */

import {
  Column,
  PrimaryGeneratedColumn,
  CreateDateColumn,
  Entity,
} from 'typeorm';

export enum DocumentType {
  LOGO = 'logo',
  IMAGE = 'image',
  PDF = 'pdf',
}

@Entity()
export class Document {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({ type: 'enum', enum: DocumentType })
  type: string;

  @Column()
  filename: string;

  @Column()
  originalName: string;

  @Column({ nullable: true })
  description?: string;

  // We don't use a relationship here because BaseEntity
  // doesn't exist as a table in the database, and if we
  // attempt to insert a record, the relation check will
  // fail. The service will need to handle the relationships
  // manually.
  @Column()
  entity: string;

  @CreateDateColumn()
  created: string;
}
