/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Issue Entity
 */

import { Entity, Column, ManyToOne, OneToMany, Generated } from 'typeorm';
import { BaseEntity, spaceRemover } from './base.entity';
import { User } from './user.entity';
import { System } from './system.entity';
import { IssueComment } from './issueComment.entity';

export enum IssueType {
  BUG = 'bug',
  FEATURE_REQUEST = 'feature request',
  PROBLEM = 'problem',
}

export enum IssueStatusType {
  OPEN = 'open',
  IN_PROGRESS = 'in progress',
  READY_TO_TEST = 'ready to test',
  FIXED = 'fixed',
  CLOSED = 'closed',
  NEED_INFORMATION = 'need information',
}

export enum IssuePriorityType {
  SHOW_STOPPER = 'show stopper',
  CRITICAL = 'critical',
  NORMAL = 'normal',
  LOW = 'low',
}

@Entity()
export class Issue extends BaseEntity {
  // This is the "ticket" number assigned to the issue.
  // The id can't be used because is in UIID format.
  @Column({ unique: true })
  @Generated('increment')
  number: number;

  // Short description of the issue.
  @Column({ transformer: spaceRemover() })
  subject: string;

  // The expanded description of the problem will be
  // stored in the column "description" inherited from
  // the BaseEntity.

  @Column({
    type: 'enum',
    enum: IssueType,
    default: IssueType.BUG,
  })
  type: string;

  @Column({
    type: 'enum',
    enum: IssueStatusType,
    default: IssueStatusType.OPEN,
  })
  status: string;

  @Column({
    type: 'enum',
    enum: IssuePriorityType,
    default: IssuePriorityType.NORMAL,
  })
  priority: string;

  // The author of the issue is stored in the column
  // authorId inherited from BaseEntity.
  // This column will store the agent assiged to the
  // issue.
  @ManyToOne(() => User)
  agent: Promise<User>;

  @ManyToOne(() => System)
  system: Promise<System>;

  @OneToMany(() => IssueComment, (issueComment) => issueComment.issue, {
    onDelete: 'CASCADE',
  })
  comments?: Promise<IssueComment[]>;
}
