/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Location Entity
 */

import { Entity, Column, OneToMany, ManyToOne, Unique } from 'typeorm';
import { BaseEntity, spaceRemover } from './base.entity';
import { Company } from './company.entity';
import { Address } from './address.entity';
import { User } from './user.entity';
import { System } from './system.entity';

export enum LocationType {
  OFFICE = 'office',
  PLANT = 'plant',
  FACTORY = 'factory',
  OTHER = 'other',
}

@Entity()
@Unique(['name', 'company'])
export class Location extends BaseEntity {
  @Column({ transformer: spaceRemover() })
  name: string;

  @Column({ type: 'enum', enum: LocationType, default: LocationType.PLANT })
  type: string;

  @Column({ default: false })
  isInnerspec: boolean;

  @Column()
  country: string;

  @Column({ nullable: true })
  street?: string;

  @Column({ nullable: true })
  street2?: string;

  @Column({ nullable: true })
  city?: string;

  @Column({ nullable: true })
  zip?: string;

  @Column({ nullable: true })
  state?: string;

  @Column({ nullable: true })
  phone?: string;

  @Column({ type: 'double', default: 0.0 })
  lat: number;

  @Column({ type: 'double', default: 0.0 })
  lng: number;

  @ManyToOne(() => Company, (company) => company.locations)
  company: Promise<Company>;

  @OneToMany(() => Address, (address) => address.location)
  addresses: Promise<Address[]>;

  @OneToMany(() => User, (user) => user.location)
  users?: Promise<User[]>;

  @OneToMany(() => System, (system) => system.location)
  systems?: Promise<System[]>;
}
