/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Product Entity
 */

import { Entity, Column, ManyToOne, OneToMany } from 'typeorm';
import { BaseEntity, spaceRemover } from './base.entity';
import { System } from './system.entity';
import { Software } from './software.entity';

export enum ProductType {
  INTEGRATED = 'integrated',
  PORTABLE = 'portable',
}
@Entity()
export class Product extends BaseEntity {
  @Column({ unique: true, transformer: spaceRemover() })
  pn: string;

  @Column({ transformer: spaceRemover() })
  name: string;

  @Column({
    type: 'enum',
    enum: ProductType,
    default: ProductType.INTEGRATED,
  })
  type: string;

  @Column({ nullable: true })
  image: string;

  @OneToMany(() => System, (system) => system.product)
  systems: Promise<System[]>;

  @ManyToOne(() => Software, (software) => software.products)
  software: Promise<Software>;
}
