/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Software Entity
 */

import { Entity, Column, OneToMany } from 'typeorm';
import { BaseEntity, spaceRemover } from './base.entity';
import { SoftwareModule } from './softwareModule.entity';
import { Product } from './product.entity';

export enum SoftwarePlatformType {
  WINDOWS = 'windows',
  ITOP = 'itop',
  ITOP2 = 'itop2',
}

@Entity()
export class Software extends BaseEntity {
  @Column({ unique: true, transformer: spaceRemover() })
  pn: string;

  @Column({
    transformer: spaceRemover(),
  })
  name: string;

  @Column({
    type: 'enum',
    enum: SoftwarePlatformType,
    default: SoftwarePlatformType.ITOP2,
  })
  type: string;

  @OneToMany(() => Product, (product) => product.software)
  products: Promise<Product>;

  @OneToMany(() => SoftwareModule, (softwareModule) => softwareModule.software)
  softwareModules: Promise<Software[]>;
}
