/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * SystemStatus Entity
 */

import { Entity, Column, ManyToOne, CreateDateColumn } from 'typeorm';
import { BaseEntity } from './base.entity';
import { System } from './system.entity';
import { SoftwareModule } from './softwareModule.entity';

export enum SubscriptionType {
  DAILY = 'daily',
  WEEKLY = 'weekly',
  MONTHLY = 'monthly',
  ANNUAL = 'annual',
  PERMANENT = 'permanent',
}
@Entity()
export class Subscription extends BaseEntity {
  // Date when the subscription was purchased or started.
  @CreateDateColumn({ type: 'timestamp' })
  poDate: string;

  // Recurrence type.
  @Column({
    type: 'enum',
    enum: SubscriptionType,
    default: SubscriptionType.MONTHLY,
  })
  type: string;

  // System the subscription is for.
  @ManyToOne(() => System, (system) => system.licenses)
  system: Promise<System>;

  // The software module the subscription is for.
  @ManyToOne(() => SoftwareModule)
  softwareModule: Promise<SoftwareModule>;
}
