/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * System Entity
 */

import {
  Entity,
  Column,
  ManyToOne,
  OneToMany,
  BeforeInsert,
  BeforeUpdate,
} from 'typeorm';
import * as bcrypt from 'bcrypt';
import { BaseEntity, spaceRemover } from './base.entity';
import { Location } from './location.entity';
import { Product } from './product.entity';
import { Subscription } from './subscription.entity';
import { SystemAccount } from './systemAccount.entity';

@Entity()
export class System extends BaseEntity {
  @Column({
    unique: true,
    transformer: spaceRemover(),
  })
  sn: string;

  @Column({
    unique: true,
    transformer: spaceRemover(),
  })
  tag: string;

  @Column()
  password: string;

  @Column()
  po: string;

  @Column()
  poDate: string;

  @ManyToOne(() => Location, (location) => location.systems)
  location: Promise<Location>;

  @ManyToOne(() => Product, (product) => product.systems)
  product: Promise<Product>;

  // TODO: change name to subscriptions!!!
  @OneToMany(() => Subscription, (subscription) => subscription.system)
  licenses: Promise<Subscription[]>;

  @OneToMany(() => SystemAccount, (systemAccount) => systemAccount.system)
  systemAccounts: Promise<SystemAccount[]>;

  @BeforeInsert()
  async setPassword() {
    this.password = await this.hashPassword(this.password);
  }

  @BeforeUpdate()
  async updatePassword() {
    if (this.password) {
      this.password = await this.hashPassword(this.password);
    }
  }

  async hashPassword(password: string): Promise<string> {
    const saltRounds = 10;
    const hashedPassword = await bcrypt.hash(password, saltRounds);
    return hashedPassword;
  }

  async checkPassword(password: string): Promise<boolean> {
    return await bcrypt.compare(password, this.password);
  }
}
