/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Systen Account Entity.
 */

import {
  Column,
  PrimaryGeneratedColumn,
  CreateDateColumn,
  UpdateDateColumn,
  ManyToOne,
  Entity,
  Unique,
} from 'typeorm';
import { User } from './user.entity';
import { System } from './system.entity';

export enum SystemAccountLevelType {
  LEVEL1 = 'level1',
  LEVEL2 = 'level2',
  LEVEL3 = 'level3',
  ADMIN = 'admin',
}

@Entity()
@Unique(['user', 'system'])
export class SystemAccount {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @ManyToOne(() => User)
  user: Promise<User>;

  @ManyToOne(() => System, (system) => system.systemAccounts)
  system: Promise<System>;

  @Column({
    type: 'enum',
    enum: SystemAccountLevelType,
    default: SystemAccountLevelType.LEVEL1,
  })
  level: string;

  @CreateDateColumn()
  created: string;

  @UpdateDateColumn()
  updated: string;
}
