/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * SystemStatus Entity
 */

import {
  Entity,
  Column,
  ManyToOne,
  CreateDateColumn,
  PrimaryGeneratedColumn,
  UpdateDateColumn,
} from 'typeorm';
import { System } from './system.entity';

// TODO: remove, this is not needed anymore
export enum StatusType {
  PORTABLE = 'portable',
  INTEGRATED = 'integrated',
}

export enum StatusModeType {
  IDLE = 'idle',
  MANUAL = 'manual',
  AUTO = 'auto',
  INSPECTING = 'inspecting',
  ERROR = 'error',
}

@Entity()
export class SystemStatus {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({ type: 'enum', enum: StatusModeType })
  mode: string;

  @Column()
  hours: number;

  @Column({ type: 'double', default: 0.0 })
  lat?: number;

  @Column({ type: 'double', default: 0.0 })
  lng?: number;

  @Column({ nullable: true, default: 0 })
  totalPass?: number;

  @Column({ nullable: true, default: 0 })
  totalFail?: number;

  @Column({ nullable: true, default: 0 })
  totalInvalid?: number;

  @Column()
  currentSetup: string;

  @Column({ type: 'timestamp' })
  time: Date;

  @ManyToOne(() => System)
  system: System;

  @CreateDateColumn()
  created: string;

  @UpdateDateColumn()
  updated: string;
}
