import { Injectable } from '@nestjs/common';
import { HttpService } from '@nestjs/common';
import { AxiosResponse } from 'axios';
import { Observable, of } from 'rxjs';
import { catchError, mergeMap } from 'rxjs/operators';
import { IAddress } from './address';

@Injectable()
export class GeocodingService {
  // TODO: move to configuration
  apiUrl = 'https://api.mapbox.com/geocoding/v5/mapbox.places';
  apiKey =
    'pk.eyJ1IjoiaW5uZXJzcGVjIiwiYSI6ImNrNHhrbTVqNDAwOGczbG1ib3psZjcwaGkifQ.vNVieKp-u3ko4JtjePa47A';

  constructor(private _http: HttpService) {}

  codeAddress(address: IAddress): Observable<AxiosResponse<number[]>> {
    const noResult = [0, 0];
    const parsedAddress = this.parseAddress(address);
    const requestString = `${this.apiUrl}/${parsedAddress}.json?limit=1&access_token=${this.apiKey}`;

    return this._http.get(requestString).pipe(
      mergeMap((res) => {
        const features = res.data.features;

        if (features.length && features[0].center != null) {
          return of(features[0].center);
        }

        return of(noResult);
      }),
      catchError(() => of(noResult)),
    );
  }

  parseAddress(address: IAddress): string {
    let parsedString = address.country;

    if (address.street) {
      parsedString = address.street;

      if (address.street2) {
        parsedString += `, ${address.street2}`;
      }
      parsedString += `, ${address.city}`;
      parsedString += `, ${address.state} ${address.zip}`;
      parsedString += `, ${address.country}`;
    }

    console.log(parsedString);

    return parsedString;
  }
}
