import { Injectable } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { SESClient, SendEmailCommand } from '@aws-sdk/client-ses';

@Injectable()
export class MailService {
  constructor(private _config: ConfigService) {}

  config() {
    return {
      region: this._config.get('awsSes.region'),
      credentials: {
        accessKeyId: this._config.get('awsSes.accessKeyId'),
        secretAccessKey: this._config.get('awsSes.secretAccessKey'),
      },
    };
  }

  params(to: string, title: string, content: string) {
    return {
      Source: 'noreply@ndt-link.com',
      Destination: {
        ToAddresses: [to],
      },
      Message: {
        Body: {
          Html: {
            Charset: 'UTF-8',
            Data: content,
          },
          Text: {
            Charset: 'UTF-8',
            Data: content,
          },
        },
        Subject: {
          Charset: 'UTF-8',
          Data: title,
        },
      },
    };
  }

  async sendEmail(to: string, title: string, content: string) {
    const ses = new SESClient(this.config());
    const sendCommand = new SendEmailCommand(this.params(to, title, content));

    try {
      await ses.send(sendCommand);
    } catch (err) {
      console.log(err);
    }
  }
}
