/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Payment Controller
 *
 * Handles routes for Payments.
 */

import { Body, Controller, Get, Param, Post, Query } from '@nestjs/common';
import { ApiTags } from '@nestjs/swagger';
import { PaymentService } from './payment.service';
import { PaymentWriteDto } from './payment.dto';
import { AuthPublic } from '@auth';

@ApiTags('Payments')
@Controller('payments')
export class PaymentController {
  constructor(public service: PaymentService) {}

  @Post('')
  newPayment(@Body() payment: PaymentWriteDto) {
    // Prepare the payment and respond with redirection URL.
    // The client then will redirect the user to that URL to
    // accept the payment.
    return this.service.createPayment(payment, "");
  }

  @AuthPublic()
  @Post('process')
  processPayment(
    @Body('token') token: string,
    @Body('payerId') payerId: string,
  ) {
    // The user has accepted to pay.
    // Here is where we really execute the payment.
    return this.service.executePayment(token);
  }
}
