import { Injectable } from '@nestjs/common';
import { TypeOrmOptionsFactory, TypeOrmModuleOptions } from '@nestjs/typeorm';
import { ConfigService } from '@nestjs/config';
import { isProduction } from '@shared/infrastructure';

@Injectable()
export class PersistenceService implements TypeOrmOptionsFactory {
  constructor(private configService: ConfigService) {}

  createTypeOrmOptions(): TypeOrmModuleOptions {
    return {
      type: 'mysql',
      host: this.configService.get('database.server'),
      port: this.configService.get('database.port'),
      database: this.configService.get('database.name'),
      username: this.configService.get('database.user'),
      password: this.configService.get('database.password'),
      bigNumberStrings: false,
      entities: [
        isProduction() ? './**/*.entity.{ts,js}' : 'dist/**/*.entity.{ts,js}',
      ],
      synchronize: true,
      logging: false,
    };
  }
}
