import { EntitySubscriberInterface, InsertEvent, Connection } from 'typeorm';
import { AuthCurrentUser } from '@auth';
import { InjectConnection } from '@nestjs/typeorm';
import { Injectable } from '@nestjs/common';
import { BaseEntity } from '@shared/domain';

@Injectable()
export class BaseEntitySubscriber
  implements EntitySubscriberInterface<BaseEntity> {
  constructor(
    @InjectConnection() readonly connection: Connection,
    public authCurrentUser: AuthCurrentUser,
  ) {
    connection.subscribers.push(this);
  }

  // Indicates that this subscriber only listen to BaseEntity events.
  listenTo() {
    return BaseEntity;
  }

  beforeInsert(event: InsertEvent<BaseEntity>) {
    if (this.authCurrentUser.user) {
      const userId = this.authCurrentUser.user.id;
      event.entity.authorId = userId;
    }
  }

  beforeUpdate(event: InsertEvent<BaseEntity>) {
    if (this.authCurrentUser.user) {
      const userId = this.authCurrentUser.user.id;
      event.entity.updatedById = userId;
    }
  }
}
