import { EntitySubscriberInterface, InsertEvent, Connection } from 'typeorm';
import { InjectConnection } from '@nestjs/typeorm';
import { Injectable } from '@nestjs/common';
import { Location } from '@shared/domain';
import { ConfigService } from '@nestjs/config';

@Injectable()
export class LocationSubscriber implements EntitySubscriberInterface<Location> {
  constructor(
    @InjectConnection() readonly connection: Connection,
    private _config: ConfigService,
  ) {
    connection.subscribers.push(this);
  }

  listenTo() {
    return Location;
  }

  beforeInsert(event: InsertEvent<Location>) {
    this.setAsInnerspec(event);
  }

  beforeUpdate(event: InsertEvent<Location>) {
    this.setAsInnerspec(event);
  }

  async setAsInnerspec(event: InsertEvent<Location>) {
    const innerspecCompanyId = this._config.get('data.innerspecCompanyId');
    const company = await event.entity.company;

    if (company.id === innerspecCompanyId) {
      event.entity.isInnerspec = true;
    }
  }
}
