import { InjectConnection } from '@nestjs/typeorm';
import { Injectable } from '@nestjs/common';
import {
  EntitySubscriberInterface,
  InsertEvent,
  Connection,
  UpdateEvent,
} from 'typeorm';
import { User, UserProfileType } from '@shared/domain';

@Injectable()
export class UserSubscriber implements EntitySubscriberInterface<User> {
  constructor(@InjectConnection() readonly connection: Connection) {
    connection.subscribers.push(this);
  }

  listenTo() {
    return User;
  }

  beforeInsert(event: InsertEvent<User>) {
    this.setProfile(event);
  }

  beforeUpdate(event: UpdateEvent<User>) {
    this.setProfile(event);
  }

  async setProfile(event: InsertEvent<User> | UpdateEvent<User>) {
    const location = await event.entity.location;

    if (event.entity.profile === UserProfileType.INNERSPEC) {
      return;
    }

    if (location.isInnerspec) {
      event.entity.profile = UserProfileType.INNERSPEC;
      return;
    }

    event.entity.profile = UserProfileType.USER;
  }
}
