/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Software Controller
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Query,
} from '@nestjs/common';
import { SoftwareService } from './software.service';
import { SoftwareCreateDto, SoftwareUpdateDto } from './software.dto';
import { ApiTags } from '@nestjs/swagger';

@ApiTags('Users')
@Controller('Software')
export class SoftwareController {
  constructor(public service: SoftwareService) {}

  @Get('withTotals')
  getManyWithTotals(
    @Query('search') search: string,
    @Query('order') order: string,
  ) {
    return this.service.find(search, order);
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Post()
  create(@Body() item: SoftwareCreateDto) {
    return this.service.addOne(item);
  }

  @Patch(':id')
  update(@Param('id') id: string, @Body() changes: SoftwareUpdateDto) {
    return this.service.updateOne(id, changes);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
