/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Software Service
 */

import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { plainToClass } from 'class-transformer';
import { Repository } from 'typeorm';
import { Software } from '@shared/domain';
import {
  SoftwareDto,
  SoftwareCreateDto,
  SoftwareListDto,
} from './software.dto';

@Injectable()
export class SoftwareService {
  baseSelectQuery = `
    SELECT
    software.*,
    COUNT(product.id) AS totalProducts,
    COUNT(software_module.id) AS totalSoftwareModules,
    COUNT(\`system\`.id) AS totalSystems
    FROM software
    LEFT JOIN product ON product.softwareId = software.id
    LEFT JOIN software_module ON software_module.softwareId = software.id
    LEFT JOIN \`system\` ON \`system\`.productId = product.id 
  `;

  constructor(@InjectRepository(Software) public repo: Repository<Software>) {}

  async find(search: string, order: string): Promise<SoftwareListDto> {
    const s = `%${search || ''}%`;
    const items: any[] = await this.repo.query(
      this.baseSelectQuery +
        `
        WHERE software.pn LIKE ? OR software.name LIKE ?
        GROUP BY software.id
        ORDER BY software.pn ${order}
      `,
      [s, s],
    );
    return plainToClass(SoftwareListDto, { total: items.length, data: items });
  }

  async findOne(id: string): Promise<SoftwareDto> {
    const items: any = await this.repo.query(
      this.baseSelectQuery +
        `
        WHERE software.id = ?
        GROUP BY software.id
      `,
      [id],
    );
    return plainToClass(SoftwareDto, items[0]);
  }

  async addOne(item: SoftwareCreateDto): Promise<SoftwareDto> {
    const newItem = await this.repo.save(Object.assign(new Software(), item));
    const savedItem = await this.repo.findOne(newItem.id);
    return this.findOne(savedItem.id);
  }

  async updateOne(id: string, changes: any): Promise<SoftwareDto> {
    const foundItem = await this.repo.findOne(id);
    if (foundItem) {
      const udpatedItem = Object.assign(foundItem, changes);
      const p = await this.repo.save(udpatedItem);
      return this.findOne(p.id);
    }

    throw new HttpException('Not Found', HttpStatus.NOT_FOUND);
  }

  deleteOne(id: string): Promise<any> {
    return this.repo.delete(id);
  }
}
