/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Software Modules Controller
 *
 * Handles routes for Software Modules.
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Query,
} from '@nestjs/common';
import { SoftwareModulesService } from './softwareModules.service';
import { SoftwareModuleCreateDto } from './softwareModules.dto';
import { ApiTags } from '@nestjs/swagger';

@ApiTags('SoftwareModules')
@Controller('softwareModules')
export class SoftwareModulesController {
  constructor(public service: SoftwareModulesService) {}

  @Get('withTotals')
  getManyWithTotals(
    @Query('search') search: string,
    @Query('order') order: string,
  ) {
    return this.service.find(search, order);
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Get('product/:productId')
  getForProduct(@Param('productId') productId: string) {
    return this.service.findForProduct(productId);
  }

  @Get('software/:softwareId')
  getForSoftware(@Param('softwareId') softwareId: string) {
    return this.service.findForSoftware(softwareId);
  }

  @Get('system/:systemId')
  getForSystem(@Param('systemId') systemId: string) {
    return this.service.findForSystem(systemId);
  }

  @Post()
  create(@Body() item: SoftwareModuleCreateDto) {
    return this.service.addOne(item);
  }

  @Patch(':id')
  update(@Param('id') id: string, @Body() changes: SoftwareModuleCreateDto) {
    return this.service.updateOne(id, changes);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
