/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * DTOs for Subscriptions.
 */

import { Expose, Exclude, Type } from 'class-transformer';
import { IsEnum, IsNotEmpty, IsOptional, MaxLength } from 'class-validator';
import { SubscriptionType } from '@shared/domain';

/**
 * DTO for List View in the front-end.
 */
@Exclude()
export class SubscriptionListDto {
  @Expose()
  total: number;

  @Expose()
  @Type(() => SubscriptionListItemDto)
  data: SubscriptionListItemDto[];
}

/**
 * DTO for each item for the List View in the front-end.
 */
@Exclude()
export class SubscriptionListItemDto {
  @Expose()
  id: string;

  @Expose()
  poDate: string;

  @Expose()
  systemSN: string;

  @Expose()
  softwareModulePN: string;

  @Expose()
  softwareModuleName: string;

  @Expose()
  type: string;

  @Expose()
  isActive: boolean;
}

/**
 * DTO for Detail View in the front-end.
 */
@Exclude()
export class SubscriptionDto {
  @Expose()
  id: string;

  @Expose()
  poId: string;

  @Expose()
  poDate: string;

  @Expose()
  systemId: string;

  @Expose()
  systemSN: string;

  @Expose()
  softwareModuleId: string;

  @Expose()
  softwareModuleName: string;

  @Expose()
  type: string;

  @Expose()
  description: string;

  @Expose()
  notes: string;

  @Expose()
  isActive: boolean;

  @Expose()
  created: string;

  @Expose()
  updated: string;
}

/**
 * DTO for creation and update using data sent from the front-end.
 * Includes decorators for validation.
 */
export class SubscriptionCreateDto {
  @IsEnum(SubscriptionType)
  type: string;

  @IsOptional()
  @MaxLength(250)
  description: string;

  @IsOptional()
  isActive: boolean;

  @IsOptional()
  notes: string;

  @IsNotEmpty()
  system: string;

  @IsNotEmpty()
  softwareModule: string;
}
