/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * System Accounts Controller
 *
 * Handles routes for System Accounts.
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Req,
} from '@nestjs/common';
import { SystemAccountsService } from './systemAccounts.service';
import { SystemAccountCreateDto } from './systemAccounts.dto';
import { ApiTags } from '@nestjs/swagger';

@ApiTags('SystemAccounts')
@Controller('systemAccounts')
export class SystemAccountsController {
  constructor(public service: SystemAccountsService) {}

  // Returns the list of Subscriptions from a remote system.
  @Get('system')
  getFromSystem(@Req() req) {
    return this.service.find(req.user.id);
  }

  @Get('system/:systemId')
  getForSystem(@Param('systemId') systemId: string) {
    return this.service.find(systemId);
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Get('user/:userId')
  getForCompany(@Param('userId') userId: string) {
    return this.service.findForUser(userId);
  }

  @Post()
  create(@Body() item: SystemAccountCreateDto) {
    return this.service.addOne(item);
  }

  @Patch(':id')
  update(@Param('id') id: string, @Body() changes: SystemAccountCreateDto) {
    return this.service.updateOne(id, changes);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
