/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * DTOs for SystemAccount Accounts.
 */

import { Expose, Exclude } from 'class-transformer';
import { IsEnum, IsNotEmpty } from 'class-validator';
import { SystemAccountLevelType } from '@shared/domain/systemAccount.entity';

@Exclude()
export class SystemAccountDto {
  @Expose()
  id: string;

  @Expose()
  userId: string;
  @Expose()
  userEmail: string;
  @Expose()
  userPassword: string;
  @Expose()
  userName: string;
  @Expose()
  userAvatar: string;

  @Expose()
  systemId: string;
  @Expose()
  systemTag: string;
  @Expose()
  systemSN: string;

  @Expose()
  productId: string;
  @Expose()
  productName: string;

  @Expose()
  level: string;

  @Expose()
  created: string;

  @Expose()
  updated: string;
}

/**
 * DTO for creation and update using data sent from the front-end.
 * Includes decorators for validation.
 */
export class SystemAccountCreateDto {
  @IsNotEmpty()
  user: string;

  @IsNotEmpty()
  system: string;

  @IsNotEmpty()
  @IsEnum(SystemAccountLevelType)
  level: string;
}
