/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * SystemStatus Controller
 *
 * Handles routes for System Status uploads from Product Connector.
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  ParseBoolPipe,
  Post,
  Query,
} from '@nestjs/common';
import { SystemStatusService } from './systemStatus.service';
import { SystemStatusCreateDto } from './systemStatus.dto';
import { ApiTags } from '@nestjs/swagger';

import { BooleanPipe } from '@shared/pipes';

@ApiTags('Systems')
@Controller('systemStatus')
export class SystemStatusController {
  constructor(public service: SystemStatusService) {}

  @Get(':date')
  getForAllSystems(@Param('date') date: string) {
    return this.service.findForAll(date);
  }

  @Get(':id/:date')
  getForSystem(
    @Param('id') id: string,
    @Param('date') date: string,
    @Query('lastOnly', BooleanPipe) lastOnly = false,
  ) {
    return this.service.findForOne(id, date, lastOnly);
  }

  @Post()
  create(@Body() items: SystemStatusCreateDto[]) {
    return this.service.addOne(items);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }
}
