/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * SystemStatus DTOs.
 */

import { Exclude, Expose } from 'class-transformer';
import { IsNotEmpty, IsOptional, IsEnum } from 'class-validator';
import { StatusType, StatusModeType } from '@shared/domain';

export class LocationSelectDto {}

@Exclude()
export class SystemStatusDto {
  @Expose()
  id: string;

  @Expose()
  type: string;

  @Expose()
  mode: string;

  @Expose()
  hours: string;

  @Expose()
  lat: string;

  @Expose()
  lng: string;

  @Expose()
  totalPass: number;

  @Expose()
  totalFail: number;

  @Expose()
  totalInvalid: number;

  @Expose()
  currentSetup: number;

  @Expose()
  time: Date;

  @Expose()
  systemId: string;
  @Expose()
  systemSN: string;

  @Expose()
  productId: string;
  @Expose()
  productName: string;

  @Expose()
  created: string;

  @Expose()
  updated: string;
}

/**
 * DTO for creation and update using data sent from the front-end.
 * Includes decorators for validation.
 */
export class SystemStatusCreateDto {
  // @IsNotEmpty()
  // @IsEnum(StatusType)
  // type?: string;

  @IsNotEmpty()
  @IsEnum(StatusModeType)
  mode: string;

  @IsNotEmpty()
  hours: number;

  @IsOptional()
  lat?: number;

  @IsOptional()
  lng?: number;

  @IsOptional()
  totalPass?: number;

  @IsOptional()
  totalFail?: number;

  @IsOptional()
  totalInvalid?: number;

  @IsNotEmpty()
  currentSetup: string;

  @IsNotEmpty()
  time: string;

  // @IsNotEmpty()
  // system?: string;
}
