/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * Systems Controller
 *
 * Handles routes for Systems.
 */

import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Query,
  Req,
} from '@nestjs/common';
import { SystemsService } from './systems.service';
import { SystemCreateDto } from './systems.dto';
import { ApiTags } from '@nestjs/swagger';

@ApiTags('Systems')
@Controller('systems')
export class SystemsController {
  constructor(public service: SystemsService) {}

  @Get('count')
  getCount() {
    return this.service.count();
  }

  @Get('withTotals')
  getManyWithTotals(
    @Query('search') search: string,
    @Query('order') order: string,
  ) {
    return this.service.find(search, order);
  }

  @Get(':id')
  getOne(@Param('id') id: string) {
    return this.service.findOne(id);
  }

  @Get('dashboard/:id')
  getForDashboard() {
    return this.service.findforDashboard();
  }

  @Get('company/:companyId')
  getForCompany(@Param('companyId') companyId: string) {
    return this.service.findForCompany(companyId);
  }

  @Get('location/:locationId')
  getForLocation(@Param('locationId') locationId: string) {
    return this.service.findForLocation(locationId);
  }

  @Post()
  create(@Body() item: SystemCreateDto, @Req() req) {
    return this.service.addOne(item, req.user);
  }

  @Patch(':id')
  update(@Param('id') id: string, @Body() changes: SystemCreateDto) {
    return this.service.updateOne(id, changes);
  }

  @Delete(':id')
  deleteOne(@Param() id: string) {
    return this.service.deleteOne(id);
  }

  @Post(':id/reset-secret')
  resetSecret(@Param('id') id: string) {
    return this.service.resetSecret(id);
  }
}
