/**
 * NDT-Link Backend.
 * Copyright 2021, Chakir Mrabet - Innerspec Technologies, Inc.
 *
 * DTOs for Systems.
 */

import { Expose, Exclude, Type } from 'class-transformer';
import { IsNotEmpty, IsOptional, MaxLength } from 'class-validator';

/**
 * DTO for List View in the front-end.
 */
@Exclude()
export class SystemListDto {
  @Expose()
  total: number;

  @Expose()
  @Type(() => SystemListItemDto)
  data: SystemListItemDto[];
}

/**
 * DTO for each item for the List View in the front-end.
 */
@Exclude()
export class SystemListItemDto {
  @Expose()
  id: string;

  @Expose()
  sn: string;

  @Expose()
  productName: string;

  @Expose()
  locationName: string;

  @Expose()
  companyName: string;

  @Expose()
  isActive: boolean;
}

/**
 * DTO for Detail View in the front-end.
 */
@Exclude()
export class SystemDto {
  @Expose()
  id: string;

  @Expose()
  sn: string;

  @Expose()
  po: string;

  @Expose()
  poDate: string;

  @Expose()
  tag: string;

  @Expose()
  productId: string;
  @Expose()
  productName: string;

  @Expose()
  softwareId: string;
  @Expose()
  softwareName: string;

  @Expose()
  locationId: string;
  @Expose()
  locationName: string;

  @Expose()
  companyId: string;
  @Expose()
  companyName: string;

  @Expose()
  description: string;

  @Expose()
  notes: string;

  @Expose()
  isActive: boolean;

  @Expose()
  created: string;

  @Expose()
  updated: string;
}

/**
 * DTO for creation and update using data sent from the front-end.
 * Includes decorators for validation.
 */
export class SystemCreateDto {
  @IsNotEmpty()
  sn: string;

  @IsNotEmpty()
  po: string;

  @IsNotEmpty()
  poDate: string;

  @IsNotEmpty()
  tag: string;

  @IsOptional()
  @MaxLength(250)
  description: string;

  @IsOptional()
  isActive: boolean;

  @IsOptional()
  notes: string;

  @IsNotEmpty()
  location: string;

  @IsNotEmpty()
  product: string;
}
