import { Module } from '@nestjs/common';
import { TypeOrmModule } from '@nestjs/typeorm';
import { join } from 'path';
import { HtmlTemplateModule } from '@shared/html-template';
import { MailModule } from '@shared/mail';
import { MulterModule } from '@nestjs/platform-express';
import { UsersService } from './users.service';
import { UsersController } from './users.controller';
import { User, Location, Company, Session } from '@shared/domain';

@Module({
  imports: [
    TypeOrmModule.forFeature([User, Location, Company, Session]),
    HtmlTemplateModule,
    MailModule,
    MulterModule.register({
      limits: {
        fileSize: 50000,
      },
      dest: join(__dirname, '..', '..', 'upload/images'),
    }),
  ],
  providers: [UsersService],
  exports: [UsersService],
  controllers: [UsersController],
})
export class UsersModule {}
